hexsha stringlengths 40 40 | size int64 7 1.05M | ext stringclasses 13
values | lang stringclasses 1
value | max_stars_repo_path stringlengths 4 269 | max_stars_repo_name stringlengths 5 108 | max_stars_repo_head_hexsha stringlengths 40 40 | max_stars_repo_licenses listlengths 1 9 | max_stars_count int64 1 191k ⌀ | max_stars_repo_stars_event_min_datetime stringlengths 24 24 ⌀ | max_stars_repo_stars_event_max_datetime stringlengths 24 24 ⌀ | max_issues_repo_path stringlengths 4 269 | max_issues_repo_name stringlengths 5 116 | max_issues_repo_head_hexsha stringlengths 40 40 | max_issues_repo_licenses listlengths 1 9 | max_issues_count int64 1 67k ⌀ | max_issues_repo_issues_event_min_datetime stringlengths 24 24 ⌀ | max_issues_repo_issues_event_max_datetime stringlengths 24 24 ⌀ | max_forks_repo_path stringlengths 4 269 | max_forks_repo_name stringlengths 5 116 | max_forks_repo_head_hexsha stringlengths 40 40 | max_forks_repo_licenses listlengths 1 9 | max_forks_count int64 1 105k ⌀ | max_forks_repo_forks_event_min_datetime stringlengths 24 24 ⌀ | max_forks_repo_forks_event_max_datetime stringlengths 24 24 ⌀ | content stringlengths 7 1.05M | avg_line_length float64 1.21 330k | max_line_length int64 6 990k | alphanum_fraction float64 0.01 0.99 | author_id stringlengths 2 40 |
|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|---|
c84808cfac1f4ecd63b78488b5f8f8efe62b79a7 | 1,360 | cpp | C++ | openicc/oyjl/oyjl-args-qml/src/utils.cpp | oyranos-cms/oyranos | 43d16a5a457bc3b8b66feabfe992f2a665723faa | [
"BSD-3-Clause"
] | 15 | 2015-03-06T07:21:55.000Z | 2021-12-31T02:07:10.000Z | openicc/oyjl/oyjl-args-qml/src/utils.cpp | oyranos-cms/oyranos | 43d16a5a457bc3b8b66feabfe992f2a665723faa | [
"BSD-3-Clause"
] | 64 | 2015-02-09T11:07:32.000Z | 2022-03-26T13:03:05.000Z | openicc/oyjl/oyjl-args-qml/src/utils.cpp | oyranos-cms/oyranos | 43d16a5a457bc3b8b66feabfe992f2a665723faa | [
"BSD-3-Clause"
] | 7 | 2015-05-23T23:17:04.000Z | 2021-06-24T13:27:30.000Z | /** @file utils.cpp
*
* Oyjl JSON QML is a graphical renderer of UI files.
*
* @par Copyright:
* 2018 (C) Kai-Uwe Behrmann
* All Rights reserved.
*
* @par License:
* MIT <http://www.opensource.org/licenses/mit-license.php>
* @since 2018/02/26
*
* logging and helpers
... | 25.185185 | 104 | 0.622059 | oyranos-cms |
c849e8581b5e8e8e0e89922c6027abdd9ef692de | 2,517 | cpp | C++ | op2orig/apps/c/aero/aero_plain/dp/openmp4/dirichlet_omp4kernel.cpp | octurion/ecoop-artifact | 4afd9c44bddbd365141b0e3e38b26f971d5dd898 | [
"MIT"
] | null | null | null | op2orig/apps/c/aero/aero_plain/dp/openmp4/dirichlet_omp4kernel.cpp | octurion/ecoop-artifact | 4afd9c44bddbd365141b0e3e38b26f971d5dd898 | [
"MIT"
] | null | null | null | op2orig/apps/c/aero/aero_plain/dp/openmp4/dirichlet_omp4kernel.cpp | octurion/ecoop-artifact | 4afd9c44bddbd365141b0e3e38b26f971d5dd898 | [
"MIT"
] | null | null | null | //
// auto-generated by op2.py
//
//user function
//user function
void dirichlet_omp4_kernel(int *map0, int map0size, double *data0, int dat0size,
int *col_reord, int set_size1, int start, int end,
int num_teams, int nthread);
// host stub function
void op_par_lo... | 26.494737 | 90 | 0.609853 | octurion |
c84a127c1f0dc3d83ea406232d4c3d9d58291fcd | 16,922 | cpp | C++ | src/cloud_scene.cpp | JakubLukas/LumixCloudSystem | 42a8cbffb54c12fec8e5bd130fcbf83b133bccb0 | [
"MIT"
] | 4 | 2017-02-21T05:00:43.000Z | 2020-10-26T20:01:08.000Z | src/cloud_scene.cpp | JakubLukas/LumixCloudSystem | 42a8cbffb54c12fec8e5bd130fcbf83b133bccb0 | [
"MIT"
] | 1 | 2020-10-13T00:50:39.000Z | 2020-10-13T00:50:39.000Z | src/cloud_scene.cpp | JakubLukas/LumixCloudSystem | 42a8cbffb54c12fec8e5bd130fcbf83b133bccb0 | [
"MIT"
] | null | null | null | #include "cloud_scene.h"
#include "engine/universe/universe.h"
#include "engine/iallocator.h"
#include "engine/associative_array.h"
#include "engine/property_register.h"
#include "engine/serializer.h"
#include "engine/blob.h"
#include "engine/engine.h"
#include "engine/resource.h"
#include "engine/resource_manager_bas... | 27.0752 | 144 | 0.698322 | JakubLukas |
c84c3ed67f1c9b0a60038280b30f437d53cd1850 | 2,370 | cpp | C++ | SherbertEngine Project/SherbertEngine/Pass.cpp | JDSherbert/Sherbert-Engine | e7a22035b077c78fc324b3ae3cb33a4fe1a5487d | [
"MIT"
] | 1 | 2022-02-22T18:27:00.000Z | 2022-02-22T18:27:00.000Z | SherbertEngine Project/SherbertEngine/Pass.cpp | JDSherbert/Sherbert-Engine | e7a22035b077c78fc324b3ae3cb33a4fe1a5487d | [
"MIT"
] | null | null | null | SherbertEngine Project/SherbertEngine/Pass.cpp | JDSherbert/Sherbert-Engine | e7a22035b077c78fc324b3ae3cb33a4fe1a5487d | [
"MIT"
] | null | null | null | #include "Pass.h"
#include "RenderGraphCompileException.h"
#include "RenderTarget.h"
#include "DepthStencil.h"
#include <sstream>
#include "SherbertENgine_Utilities.h"
#include "Sink.h"
#include "Source.h"
namespace n_SherbRendergraphpass
{
Pass::Pass( std::string name ) noexcept
:
name( std::move( name ) )
{}
... | 20.789474 | 99 | 0.631646 | JDSherbert |
c84c53fb926352722ed49059eb27eb7f1218bba7 | 4,393 | cc | C++ | src/shared/platform/platform_tests.cc | MicrohexHQ/nacl_contracts | 3efab5eecb3cf7ba43f2d61000e65918aa4ba77a | [
"BSD-3-Clause"
] | 6 | 2015-02-06T23:41:01.000Z | 2015-10-21T03:08:51.000Z | src/shared/platform/platform_tests.cc | MicrohexHQ/nacl_contracts | 3efab5eecb3cf7ba43f2d61000e65918aa4ba77a | [
"BSD-3-Clause"
] | null | null | null | src/shared/platform/platform_tests.cc | MicrohexHQ/nacl_contracts | 3efab5eecb3cf7ba43f2d61000e65918aa4ba77a | [
"BSD-3-Clause"
] | 1 | 2015-11-08T10:18:42.000Z | 2015-11-08T10:18:42.000Z | /*
* Copyright 2010 The Native Client Authors. All rights reserved.
* Use of this source code is governed by a BSD-style license that can
* be found in the LICENSE file.
*/
#include <stdio.h>
#include "native_client/src/include/portability.h"
#include "native_client/src/include/checked_cast.h"
#if NACL_WINDOWS... | 23.875 | 79 | 0.567266 | MicrohexHQ |
c84f7c4de90997f8e7a9ce448769a26f0cf21116 | 3,089 | hpp | C++ | tracy/common/TracySocket.hpp | MacdaraTwomey/KeepTime | eacfecbaf9a401a87c5c8df09a6d2a2c4d24c3d5 | [
"MIT"
] | 19 | 2020-02-11T19:57:41.000Z | 2022-02-20T14:11:33.000Z | tracy/common/TracySocket.hpp | MacdaraTwomey/KeepTime | eacfecbaf9a401a87c5c8df09a6d2a2c4d24c3d5 | [
"MIT"
] | null | null | null | tracy/common/TracySocket.hpp | MacdaraTwomey/KeepTime | eacfecbaf9a401a87c5c8df09a6d2a2c4d24c3d5 | [
"MIT"
] | 5 | 2019-11-05T17:38:33.000Z | 2022-03-04T12:49:58.000Z | #ifndef __TRACYSOCKET_HPP__
#define __TRACYSOCKET_HPP__
#include <atomic>
#include <stdint.h>
#include "TracyForceInline.hpp"
struct addrinfo;
struct sockaddr;
namespace tracy
{
#ifdef _WIN32
void InitWinSock();
#endif
class Socket
{
public:
Socket();
Socket( int sock );
~Socket();
bool Connect( ... | 20.058442 | 67 | 0.626416 | MacdaraTwomey |
c84fe53161f66107acff20d8f88171fd6197244b | 3,386 | cpp | C++ | C++/CreateYourOwnShell/ass02CreateYourOwnShell/shelpers.cpp | znickle24/ZanderProjects | 674d72d2cba888d0605d9bc8230ecee724ec09b1 | [
"MIT"
] | null | null | null | C++/CreateYourOwnShell/ass02CreateYourOwnShell/shelpers.cpp | znickle24/ZanderProjects | 674d72d2cba888d0605d9bc8230ecee724ec09b1 | [
"MIT"
] | null | null | null | C++/CreateYourOwnShell/ass02CreateYourOwnShell/shelpers.cpp | znickle24/ZanderProjects | 674d72d2cba888d0605d9bc8230ecee724ec09b1 | [
"MIT"
] | null | null | null | #include "shelpers.hpp"
#include <assert.h>
/*
text handling functions
*/
bool splitOnSymbol(std::vector<std::string>& words, int i, char c){
if(words[i].size() < 2){ return false; }
int pos;
if((pos = words[i].find(c)) != std::string::npos){
if(pos == 0){
//starts with symbol
words.insert(words.begin(... | 25.651515 | 102 | 0.552274 | znickle24 |
c8518e8b006549f430517d66945e12d3e771e7fe | 1,609 | cpp | C++ | src/Screens/ShowOrientationScreen.cpp | underscoredotspace/watchy-revolution | 9403314a47e53565e36172c37a75d9622657c51f | [
"MIT"
] | null | null | null | src/Screens/ShowOrientationScreen.cpp | underscoredotspace/watchy-revolution | 9403314a47e53565e36172c37a75d9622657c51f | [
"MIT"
] | null | null | null | src/Screens/ShowOrientationScreen.cpp | underscoredotspace/watchy-revolution | 9403314a47e53565e36172c37a75d9622657c51f | [
"MIT"
] | null | null | null | #include "ShowOrientationScreen.h"
#include "OptimaLTStd12pt7b.h"
#include "Watchy.h"
void ShowOrientationScreen::showMe() {
Watchy::display.fillScreen(bgColor);
Watchy::display.setCursor(0,0);
Accel acc;
if (Watchy::sensor.getAccel(acc)) {
Watchy::display.printf("\n X: %d", acc.x);
Watchy::display.p... | 25.539683 | 52 | 0.640771 | underscoredotspace |
c85315372dc02dd2d409a8e214ea587101241a43 | 224 | hpp | C++ | RuneFramework/vendor/glm/glm/mat3x2.hpp | IvanNSBS/Rune-Engine | b0e42b143f85da44381a498a9935355083429be4 | [
"MIT"
] | 6,097 | 2015-01-03T02:11:03.000Z | 2022-03-31T03:29:58.000Z | RuneFramework/vendor/glm/glm/mat3x2.hpp | IvanNSBS/Rune-Engine | b0e42b143f85da44381a498a9935355083429be4 | [
"MIT"
] | 1,340 | 2017-08-29T15:28:41.000Z | 2022-03-31T23:45:51.000Z | RuneFramework/vendor/glm/glm/mat3x2.hpp | IvanNSBS/Rune-Engine | b0e42b143f85da44381a498a9935355083429be4 | [
"MIT"
] | 2,057 | 2015-01-03T00:07:34.000Z | 2022-03-31T22:49:17.000Z | /// @ref core
/// @file glm/mat3x2.hpp
#pragma once
#include "./ext/matrix_double3x2.hpp"
#include "./ext/matrix_double3x2_precision.hpp"
#include "./ext/matrix_float3x2.hpp"
#include "./ext/matrix_float3x2_precision.hpp"
| 22.4 | 47 | 0.745536 | IvanNSBS |
c85346f8ccbc00b0b8c9f2fd6caf26f8556f49d7 | 14,102 | cc | C++ | chromium/chrome/installer/util/set_reg_value_work_item_unittest.cc | wedataintelligence/vivaldi-source | 22a46f2c969f6a0b7ca239a05575d1ea2738768c | [
"BSD-3-Clause"
] | null | null | null | chromium/chrome/installer/util/set_reg_value_work_item_unittest.cc | wedataintelligence/vivaldi-source | 22a46f2c969f6a0b7ca239a05575d1ea2738768c | [
"BSD-3-Clause"
] | null | null | null | chromium/chrome/installer/util/set_reg_value_work_item_unittest.cc | wedataintelligence/vivaldi-source | 22a46f2c969f6a0b7ca239a05575d1ea2738768c | [
"BSD-3-Clause"
] | null | null | null | // Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
#include <windows.h>
#include <string>
#include "base/bind.h"
#include "base/files/file_path.h"
#include "base/macros.h"
#include "base/memory/scope... | 36.533679 | 80 | 0.625301 | wedataintelligence |
c853b743454125b29bafb642d1cebe799f80663d | 1,263 | cc | C++ | chrome/browser/google_apis/event_logger.cc | hujiajie/pa-chromium | 1816ff80336a6efd1616f9e936880af460b1e105 | [
"BSD-3-Clause-No-Nuclear-License-2014",
"BSD-3-Clause"
] | 2 | 2020-05-03T06:33:56.000Z | 2021-11-14T18:39:42.000Z | chrome/browser/google_apis/event_logger.cc | hujiajie/pa-chromium | 1816ff80336a6efd1616f9e936880af460b1e105 | [
"BSD-3-Clause-No-Nuclear-License-2014",
"BSD-3-Clause"
] | null | null | null | chrome/browser/google_apis/event_logger.cc | hujiajie/pa-chromium | 1816ff80336a6efd1616f9e936880af460b1e105 | [
"BSD-3-Clause-No-Nuclear-License-2014",
"BSD-3-Clause"
] | null | null | null | // Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
#include "chrome/browser/google_apis/event_logger.h"
#include "base/strings/stringprintf.h"
namespace google_apis {
EventLogger::Event::Event(int i... | 22.963636 | 73 | 0.707838 | hujiajie |
c8545b568dfb334eead1802acd50651402b756df | 53,946 | cpp | C++ | test/examples/code/3rdparty/assimp/detail/LWOLoader.cpp | maikebing/vpp | efa6c32f898e103d749764ce3a0b7dc29d6e9a51 | [
"BSD-2-Clause"
] | null | null | null | test/examples/code/3rdparty/assimp/detail/LWOLoader.cpp | maikebing/vpp | efa6c32f898e103d749764ce3a0b7dc29d6e9a51 | [
"BSD-2-Clause"
] | null | null | null | test/examples/code/3rdparty/assimp/detail/LWOLoader.cpp | maikebing/vpp | efa6c32f898e103d749764ce3a0b7dc29d6e9a51 | [
"BSD-2-Clause"
] | null | null | null | /*
---------------------------------------------------------------------------
Open Asset Import Library (assimp)
---------------------------------------------------------------------------
Copyright (c) 2006-2016, assimp team
All rights reserved.
Redistribution and use of this software in source and binary forms,
w... | 36.54878 | 146 | 0.528306 | maikebing |
c855845881a89da848a594f5715c81861be6df6d | 1,506 | cc | C++ | third_party/blink/renderer/modules/media_controls/elements/media_control_div_element.cc | mghgroup/Glide-Browser | 6a4c1eaa6632ec55014fee87781c6bbbb92a2af5 | [
"BSD-3-Clause-No-Nuclear-License-2014",
"BSD-3-Clause"
] | null | null | null | third_party/blink/renderer/modules/media_controls/elements/media_control_div_element.cc | mghgroup/Glide-Browser | 6a4c1eaa6632ec55014fee87781c6bbbb92a2af5 | [
"BSD-3-Clause-No-Nuclear-License-2014",
"BSD-3-Clause"
] | null | null | null | third_party/blink/renderer/modules/media_controls/elements/media_control_div_element.cc | mghgroup/Glide-Browser | 6a4c1eaa6632ec55014fee87781c6bbbb92a2af5 | [
"BSD-3-Clause-No-Nuclear-License-2014",
"BSD-3-Clause"
] | 2 | 2021-01-05T23:43:46.000Z | 2021-01-07T23:36:34.000Z | // Copyright 2017 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
#include "third_party/blink/renderer/modules/media_controls/elements/media_control_div_element.h"
#include "third_party/blink/public/platform/web_size.h"... | 33.466667 | 101 | 0.791501 | mghgroup |
c856fe947589d7709e9114760b5dee39312e1abf | 942 | cpp | C++ | Challenge-2021-08/03_subsets_II.cpp | qiufengyu/LetsCode | 196fae0bf5c78ee20d05798a9439596e702fdb24 | [
"MIT"
] | null | null | null | Challenge-2021-08/03_subsets_II.cpp | qiufengyu/LetsCode | 196fae0bf5c78ee20d05798a9439596e702fdb24 | [
"MIT"
] | null | null | null | Challenge-2021-08/03_subsets_II.cpp | qiufengyu/LetsCode | 196fae0bf5c78ee20d05798a9439596e702fdb24 | [
"MIT"
] | null | null | null | #include "../header.h"
class Solution {
vector<int> temp;
vector<vector<int>> res;
public:
vector<vector<int>> subsetsWithDup(vector<int>& nums) {
int n = nums.size();
sort(nums.begin(), nums.end());
int total = 1 << n; // n <= 10
for (int mask = 0; mask < total; ++mask) {
... | 30.387097 | 86 | 0.381104 | qiufengyu |
c8578edc0e09188fb1cc224df4794f9b3731131b | 5,386 | cpp | C++ | src/io/frontend_io/unvmf_io_handler.cpp | hsungyang/poseidonos | 0f523b36ccf0d70726364395ea96ac6ae3b845c3 | [
"BSD-3-Clause"
] | 38 | 2021-04-06T03:20:55.000Z | 2022-03-02T09:33:28.000Z | src/io/frontend_io/unvmf_io_handler.cpp | gye-ul/poseidonos | bce8fe2cd1f36ede8647446ecc4cf8a9749e6918 | [
"BSD-3-Clause"
] | 19 | 2021-04-08T02:27:44.000Z | 2022-03-23T00:59:04.000Z | src/io/frontend_io/unvmf_io_handler.cpp | gye-ul/poseidonos | bce8fe2cd1f36ede8647446ecc4cf8a9749e6918 | [
"BSD-3-Clause"
] | 28 | 2021-04-08T04:39:18.000Z | 2022-03-24T05:56:00.000Z | /*
* BSD LICENSE
* Copyright (c) 2021 Samsung Electronics Corporation
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions
* are met:
*
* * Redistributions of source code must retain th... | 34.305732 | 127 | 0.630524 | hsungyang |
c8586c1a94963d672798450f73fa3184979e0da4 | 1,424 | hpp | C++ | src/CardCanvas/AlarmPanelCardCanvas.hpp | RobinSinghNanda/Home-assistant-display | 6f59104012c0956b54d4b55e190aa89941c2c1af | [
"MIT"
] | 2 | 2020-10-23T19:53:56.000Z | 2020-11-06T08:59:48.000Z | src/CardCanvas/AlarmPanelCardCanvas.hpp | RobinSinghNanda/Home-assistant-display | 6f59104012c0956b54d4b55e190aa89941c2c1af | [
"MIT"
] | null | null | null | src/CardCanvas/AlarmPanelCardCanvas.hpp | RobinSinghNanda/Home-assistant-display | 6f59104012c0956b54d4b55e190aa89941c2c1af | [
"MIT"
] | null | null | null | #ifndef __ALARMPANELCARDCANVAS_H__
#define __ALARMPANELCARDCANVAS_H__
#include "CardCanvas.hpp"
#include <Canvas/ImageCanvas.hpp>
#include <Canvas/TextCanvas.hpp>
#include <Canvas/NumberPadCanvas.hpp>
#include "LovelaceConfig/AlarmPanelCardConfig.hpp"
#include "HomeAssistant/Components/AlarmControlPanel.hpp"
#include ... | 35.6 | 141 | 0.707865 | RobinSinghNanda |
c859a157c7f49e0b6967e486a0e93c0fcd4b708b | 1,369 | cpp | C++ | src/layers/reductions/layer_reduction.cpp | ilveroluca/eddl | 02e37c0dfb674468495f4d0ae3c159de3b2d3cc0 | [
"MIT"
] | null | null | null | src/layers/reductions/layer_reduction.cpp | ilveroluca/eddl | 02e37c0dfb674468495f4d0ae3c159de3b2d3cc0 | [
"MIT"
] | null | null | null | src/layers/reductions/layer_reduction.cpp | ilveroluca/eddl | 02e37c0dfb674468495f4d0ae3c159de3b2d3cc0 | [
"MIT"
] | null | null | null | /*
* EDDL Library - European Distributed Deep Learning Library.
* Version: 0.6
* copyright (c) 2020, Universidad Politécnica de Valencia (UPV), PRHLT Research Centre
* Date: April 2020
* Author: PRHLT Research Centre, UPV, (rparedes@prhlt.upv.es), (jon@prhlt.upv.es)
* All rights reserved
*/
#include <cstdio>
#include... | 22.816667 | 108 | 0.623083 | ilveroluca |
c85a888f950d03f12eb04df28a77ace0f3a9575d | 1,033 | cpp | C++ | src/core/tests/visitors/op/shuffle_channels.cpp | ryanloney/openvino-1 | 4e0a740eb3ee31062ba0df88fcf438564f67edb7 | [
"Apache-2.0"
] | 1,127 | 2018-10-15T14:36:58.000Z | 2020-04-20T09:29:44.000Z | src/core/tests/visitors/op/shuffle_channels.cpp | ryanloney/openvino-1 | 4e0a740eb3ee31062ba0df88fcf438564f67edb7 | [
"Apache-2.0"
] | 439 | 2018-10-20T04:40:35.000Z | 2020-04-19T05:56:25.000Z | src/core/tests/visitors/op/shuffle_channels.cpp | ryanloney/openvino-1 | 4e0a740eb3ee31062ba0df88fcf438564f67edb7 | [
"Apache-2.0"
] | 414 | 2018-10-17T05:53:46.000Z | 2020-04-16T17:29:53.000Z | // Copyright (C) 2018-2022 Intel Corporation
// SPDX-License-Identifier: Apache-2.0
//
#include "gtest/gtest.h"
#include "ngraph/ngraph.hpp"
#include "ngraph/opsets/opset3.hpp"
#include "util/visitor.hpp"
using namespace std;
using namespace ngraph;
using ngraph::test::NodeBuilder;
TEST(attributes, shuffle_channels_... | 33.322581 | 81 | 0.744434 | ryanloney |
c85cd69564ab376bf6c9d4021dd8179a07276dd4 | 1,308 | cpp | C++ | CodeForces Problems/B_Kayaking.cpp | AshishSingh13s/HactoberFest21 | 93cdfc80a971cd8904f313e5b0dd339642366854 | [
"Unlicense"
] | 1 | 2021-11-21T03:37:18.000Z | 2021-11-21T03:37:18.000Z | CodeForces Problems/B_Kayaking.cpp | sonishsinghal/HactoberFest21 | c4ca69f2f8198585db9914e8b113290dad07a188 | [
"Unlicense"
] | 1 | 2021-10-06T04:41:55.000Z | 2021-10-06T04:41:55.000Z | CodeForces Problems/B_Kayaking.cpp | sonishsinghal/HactoberFest21 | c4ca69f2f8198585db9914e8b113290dad07a188 | [
"Unlicense"
] | 1 | 2021-10-08T12:31:04.000Z | 2021-10-08T12:31:04.000Z | #include<bits/stdc++.h>
using namespace std;
#define ll long long int
int main()
{
ios_base::sync_with_stdio(0);
cin.tie(0);
int t=1;
while(t--)
{
int n;
cin>>n;
int p=2*n;
vector<int> a;
for(int i=0;i<p;i++)
{
int x;
... | 23.357143 | 49 | 0.219419 | AshishSingh13s |
c85d86987fb543faa3254b804a2e7fd72d09acd4 | 1,927 | cpp | C++ | src/lsm6_imu.cpp | agv-polsl/minimu | 2ec1abeb5fad2f0ba20e435879576bb7d71267af | [
"MIT"
] | null | null | null | src/lsm6_imu.cpp | agv-polsl/minimu | 2ec1abeb5fad2f0ba20e435879576bb7d71267af | [
"MIT"
] | 15 | 2020-04-19T12:46:38.000Z | 2020-09-08T12:00:06.000Z | src/lsm6_imu.cpp | agv-polsl/minimu | 2ec1abeb5fad2f0ba20e435879576bb7d71267af | [
"MIT"
] | 1 | 2020-09-08T14:20:35.000Z | 2020-09-08T14:20:35.000Z | #include "minimu/lsm6_imu.h"
namespace minimu {
Lsm6_imu::Lsm6_imu(const uint8_t adapter_nr, const sa0_state device_mode)
: Minimu_i2c_device<lsm6_regs_addr, lsm6_id>{adapter_nr, device_mode} {
default_setup();
}
point3d Lsm6_imu::read_3d_burst(lsm6_regs_addr start_addr, double scale) {
constexpr size_t ... | 30.109375 | 80 | 0.736378 | agv-polsl |
c85e5173312b5f3477fd296fdc15bd5e90fa9f88 | 3,109 | cpp | C++ | core/src/bind/hotkey/clipboard.cpp | pit-ray/win-vind | 7386f6f7528d015ce7f1a5ae230d6e63f9492df9 | [
"MIT"
] | 731 | 2020-05-07T06:22:59.000Z | 2022-03-31T16:36:03.000Z | core/src/bind/hotkey/clipboard.cpp | pit-ray/win-vind | 7386f6f7528d015ce7f1a5ae230d6e63f9492df9 | [
"MIT"
] | 67 | 2020-07-20T19:46:42.000Z | 2022-03-31T15:34:47.000Z | core/src/bind/hotkey/clipboard.cpp | pit-ray/win-vind | 7386f6f7528d015ce7f1a5ae230d6e63f9492df9 | [
"MIT"
] | 15 | 2021-01-29T04:49:11.000Z | 2022-03-04T22:16:31.000Z | #include "bind/hotkey/clipboard.hpp"
#include <windows.h>
#include "key/char_logger.hpp"
#include "mode.hpp"
#include "key/ntype_logger.hpp"
#include "util/def.hpp"
#include "bind/emu/edi_change_mode.hpp"
#include "bind/mode/change_mode.hpp"
#include "io/keybrd.hpp"
#include "io/mouse.hpp"
#include "key/key_absorbe... | 24.674603 | 74 | 0.62496 | pit-ray |
c8603f1d5f07e9c96c16fe832d53d2c466648886 | 8,257 | cpp | C++ | src/FullSystem/Residuals.cpp | danielecolautti/DSO-Server | 34968398f9834c9177ca373d9a3b3d2e13c2ee86 | [
"Apache-2.0"
] | null | null | null | src/FullSystem/Residuals.cpp | danielecolautti/DSO-Server | 34968398f9834c9177ca373d9a3b3d2e13c2ee86 | [
"Apache-2.0"
] | null | null | null | src/FullSystem/Residuals.cpp | danielecolautti/DSO-Server | 34968398f9834c9177ca373d9a3b3d2e13c2ee86 | [
"Apache-2.0"
] | null | null | null | /**
* This file is part of DSO.
*
* Copyright 2016 Technical University of Munich and Intel.
* Developed by Jakob Engel <engelj at in dot tum dot de>,
* for more information see <http://vision.in.tum.de/dso>.
* If you use this code, please cite the respective publications as
* listed on the above website.
*
* DSO is f... | 25.021212 | 127 | 0.672884 | danielecolautti |
c86579f5f0c690af1eb201a088dea19a608e2f03 | 13,511 | cpp | C++ | openEAR-0.1.0/src/semaineEmmaSender.cpp | trimlab/Voice-Emotion-Detection | c7272dd2f70e2d4b8eee304e68578494d7ef624c | [
"MIT"
] | null | null | null | openEAR-0.1.0/src/semaineEmmaSender.cpp | trimlab/Voice-Emotion-Detection | c7272dd2f70e2d4b8eee304e68578494d7ef624c | [
"MIT"
] | null | null | null | openEAR-0.1.0/src/semaineEmmaSender.cpp | trimlab/Voice-Emotion-Detection | c7272dd2f70e2d4b8eee304e68578494d7ef624c | [
"MIT"
] | null | null | null | /*F******************************************************************************
*
* openSMILE - open Speech and Music Interpretation by Large-space Extraction
* the open-source Munich Audio Feature Extraction Toolkit
* Copyright (C) 2008-2009 Florian Eyben, Martin Woellmer, Bjoern Schuller
*
*
* Institu... | 36.814714 | 153 | 0.735253 | trimlab |
c866c78b5684f590d0b29f2d59e2c2bf9ddc3ee9 | 2,660 | cpp | C++ | controllers/eyebot_circle/footbot_circle.cpp | ssriramana93/EnvClassify | 56c1b1965403d08fd3c1213a2bc67a27a9c1ebf8 | [
"MIT"
] | 32 | 2016-01-04T12:32:46.000Z | 2022-03-05T11:27:49.000Z | controllers/eyebot_circle/footbot_circle.cpp | ssriramana93/EnvClassify | 56c1b1965403d08fd3c1213a2bc67a27a9c1ebf8 | [
"MIT"
] | 11 | 2016-04-14T18:58:52.000Z | 2022-03-24T20:26:32.000Z | controllers/eyebot_circle/footbot_circle.cpp | ssriramana93/EnvClassify | 56c1b1965403d08fd3c1213a2bc67a27a9c1ebf8 | [
"MIT"
] | 45 | 2015-06-14T16:14:06.000Z | 2022-03-06T22:54:57.000Z | /* Include the controller definition */
#include "footbot_circle.h"
/* Function definitions for XML parsing */
#include <argos3/core/utility/configuration/argos_configuration.h>
/* Function definitions for logging */
#include <argos3/core/utility/logging/argos_log.h>
/****************************************/
/*******... | 32.839506 | 81 | 0.583459 | ssriramana93 |
c8693718ddb23623f100949263ce05876f299ada | 2,164 | cpp | C++ | Chapter04/CvDraw/main.cpp | PacktPublishing/Hands-On-Algorithms-for-Computer-Vision | 204c69a357f42ac9b7ac641df697cf52ced96416 | [
"MIT"
] | 36 | 2018-06-03T13:53:48.000Z | 2022-03-15T13:52:47.000Z | Chapter04/CvDraw/main.cpp | PacktPublishing/Hands-On-Algorithms-for-Computer-Vision | 204c69a357f42ac9b7ac641df697cf52ced96416 | [
"MIT"
] | null | null | null | Chapter04/CvDraw/main.cpp | PacktPublishing/Hands-On-Algorithms-for-Computer-Vision | 204c69a357f42ac9b7ac641df697cf52ced96416 | [
"MIT"
] | 21 | 2018-08-07T11:04:05.000Z | 2021-04-15T12:51:41.000Z | #include <iostream>
#include <opencv2/opencv.hpp>
using namespace std;
using namespace cv;
int main()
{
Mat image = imread("Test.png");
if(image.empty())
{
cout << "Empty input image!";
return -1;
}
// ***************************** Arrowed line *****************************
Po... | 23.521739 | 79 | 0.40573 | PacktPublishing |
c8695aa9b61aed42bfba5bfff680886bd68e6231 | 2,411 | cpp | C++ | Abacus.cpp | south37/topcoder | 9edee3f723189ccdbecb1cbc5c186a99f392e6dd | [
"MIT"
] | null | null | null | Abacus.cpp | south37/topcoder | 9edee3f723189ccdbecb1cbc5c186a99f392e6dd | [
"MIT"
] | null | null | null | Abacus.cpp | south37/topcoder | 9edee3f723189ccdbecb1cbc5c186a99f392e6dd | [
"MIT"
] | null | null | null | #include <iostream>
#include <vector>
#define N 6
#define M 12
class Abacus {
public:
std::vector <std::string> add(std::vector <std::string> original, int val) {
int c = changeToLong(original) + val;
std::vector <std::string> result(6, "oooooooooooo");
changeToVector(result, c);
r... | 30.518987 | 135 | 0.491083 | south37 |
c86aa93d2153b2b8dccc9022319c3a2dc8900ade | 962 | cpp | C++ | src/vcpkg/buildenvironment.cpp | autoantwort/vcpkg-tool | fb3475040d256bc0d744fa72a20b0a9d103d48b3 | [
"MIT"
] | null | null | null | src/vcpkg/buildenvironment.cpp | autoantwort/vcpkg-tool | fb3475040d256bc0d744fa72a20b0a9d103d48b3 | [
"MIT"
] | null | null | null | src/vcpkg/buildenvironment.cpp | autoantwort/vcpkg-tool | fb3475040d256bc0d744fa72a20b0a9d103d48b3 | [
"MIT"
] | null | null | null | #include <vcpkg/buildenvironment.h>
#include <vcpkg/tools.h>
#include <vcpkg/triplet.h>
#include <vcpkg/vcpkgpaths.h>
namespace vcpkg
{
System::Command make_cmake_cmd(const VcpkgPaths& paths,
const fs::path& cmake_script,
std::vector<System::CMa... | 43.727273 | 109 | 0.689189 | autoantwort |
c86d57bdeb68ab5679d8c8c8680ac197c9954af8 | 411 | hh | C++ | iod/bind_method.hh | Manu343726/iod | 72d5f3ccd379b03e01ffecd6513ab3f2593af5f4 | [
"MIT"
] | 488 | 2015-01-04T15:35:49.000Z | 2022-03-09T19:15:19.000Z | thirdparty/iod/iod/bind_method.hh | pdebus/MTVMTL | 65a7754b34d1f6a1e86d15e3c2d4346b9418414f | [
"MIT"
] | 20 | 2015-02-17T18:49:51.000Z | 2019-11-04T10:06:04.000Z | thirdparty/iod/iod/bind_method.hh | pdebus/MTVMTL | 65a7754b34d1f6a1e86d15e3c2d4346b9418414f | [
"MIT"
] | 52 | 2015-01-02T17:14:11.000Z | 2020-06-22T14:40:01.000Z | #pragma once
namespace iod
{
template <typename O, typename R, typename... ARGS>
auto bind_method(O& o, R (O::*m)(ARGS...))
{
return [&o, m] (ARGS... a) { return (o.*m)(std::forward<ARGS>(a)...); };
}
template <typename O, typename R, typename... ARGS>
auto bind_method(O& o, R (O::*m)(ARGS...) const)... | 21.631579 | 76 | 0.542579 | Manu343726 |
c86d975e9b89e79c786522a62419a71c386e11a4 | 3,106 | cpp | C++ | test/focus-cycle.cpp | 8l/swm | dfa4ba130ff39aa0bf96b991bca34fba086b333b | [
"BSD-2-Clause"
] | null | null | null | test/focus-cycle.cpp | 8l/swm | dfa4ba130ff39aa0bf96b991bca34fba086b333b | [
"BSD-2-Clause"
] | null | null | null | test/focus-cycle.cpp | 8l/swm | dfa4ba130ff39aa0bf96b991bca34fba086b333b | [
"BSD-2-Clause"
] | null | null | null | #include <iostream>
#include <vector>
#include <UnitTest++.h>
#include "model/focus-cycle.h"
#include "logging/logging.h"
#include "logging/stream.h"
const int last_window = 9;
StreamLog log(std::cerr);
struct FocusCycleFixture
{
FocusCycle cycle;
std::vector<Window> windows;
FocusCycleFixture() :
... | 25.669421 | 81 | 0.594656 | 8l |
c86de741c299f5cfe6e3f3665c39031dce01f69e | 37,829 | hpp | C++ | src/ocl/jit_gen9_common_conv_kernel.hpp | uyongw/mkl-dnn | 5588edb4f12b7ddd4b25ca857acde64066fbd699 | [
"Apache-2.0"
] | 1 | 2018-04-13T01:38:53.000Z | 2018-04-13T01:38:53.000Z | src/ocl/jit_gen9_common_conv_kernel.hpp | uyongw/mkl-dnn | 5588edb4f12b7ddd4b25ca857acde64066fbd699 | [
"Apache-2.0"
] | null | null | null | src/ocl/jit_gen9_common_conv_kernel.hpp | uyongw/mkl-dnn | 5588edb4f12b7ddd4b25ca857acde64066fbd699 | [
"Apache-2.0"
] | 2 | 2021-06-29T13:24:31.000Z | 2021-06-30T12:07:02.000Z | /*******************************************************************************
* Copyright 2019 Intel Corporation
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.o... | 39.736345 | 80 | 0.486214 | uyongw |
c86fa9294611c85f7f6f0cc2435d0f86cbcd02ff | 1,075 | hpp | C++ | src/GameState/PhysicalObject/Player.hpp | Heaven31415/SpaceShooter | 385e43aa2deb8720c1b0a23834ad31de97fd25eb | [
"Zlib"
] | null | null | null | src/GameState/PhysicalObject/Player.hpp | Heaven31415/SpaceShooter | 385e43aa2deb8720c1b0a23834ad31de97fd25eb | [
"Zlib"
] | null | null | null | src/GameState/PhysicalObject/Player.hpp | Heaven31415/SpaceShooter | 385e43aa2deb8720c1b0a23834ad31de97fd25eb | [
"Zlib"
] | null | null | null | #pragma once
#include "Weapons\LaserFactory.hpp"
#include "../PhysicalObject.hpp"
#include "../../Common/Context.hpp"
#include "../../Common/Observer.hpp"
class World;
class Player : public PhysicalObject
{
public:
enum class Frame
{
Straight,
Left,
Right
};
enum class Weapon... | 29.861111 | 107 | 0.512558 | Heaven31415 |
c87016a61baadf2a9cb74fbd2a002c384803322d | 809 | hpp | C++ | include/lug/Graphics/Builder/Scene.hpp | Lugdunum3D/Lugdunum3D | b6d6907d034fdba1ffc278b96598eba1d860f0d4 | [
"MIT"
] | 275 | 2016-10-08T15:33:17.000Z | 2022-03-30T06:11:56.000Z | include/lug/Graphics/Builder/Scene.hpp | Lugdunum3D/Lugdunum3D | b6d6907d034fdba1ffc278b96598eba1d860f0d4 | [
"MIT"
] | 24 | 2016-09-29T20:51:20.000Z | 2018-05-09T21:41:36.000Z | include/lug/Graphics/Builder/Scene.hpp | Lugdunum3D/Lugdunum3D | b6d6907d034fdba1ffc278b96598eba1d860f0d4 | [
"MIT"
] | 37 | 2017-02-25T05:03:48.000Z | 2021-05-10T19:06:29.000Z | #pragma once
#include <vector>
#include <string>
#include <lug/Graphics/Resource.hpp>
#include <lug/Graphics/Scene/Scene.hpp>
namespace lug {
namespace Graphics {
class Renderer;
namespace Builder {
class LUG_GRAPHICS_API Scene {
public:
explicit Scene(Renderer& renderer);
Scene(const Scene&) = delete;
... | 16.854167 | 61 | 0.647713 | Lugdunum3D |
c8740e35a583f0aaf29da1422ef4774b7c52989c | 1,768 | cpp | C++ | SearchingAndSorting/sort_n_number_liner.cpp | xiaorancs/xr-Algorithm | 4b522b2936b986f7891756fc610917b99864c534 | [
"MIT"
] | 7 | 2017-12-11T12:42:39.000Z | 2019-11-17T15:10:26.000Z | SearchingAndSorting/sort_n_number_liner.cpp | xiaorancs/xr-Algorithm | 4b522b2936b986f7891756fc610917b99864c534 | [
"MIT"
] | 1 | 2018-08-29T12:29:51.000Z | 2018-08-29T12:29:51.000Z | SearchingAndSorting/sort_n_number_liner.cpp | xiaorancs/xr-Algorithm | 4b522b2936b986f7891756fc610917b99864c534 | [
"MIT"
] | 2 | 2018-01-29T08:26:30.000Z | 2018-08-10T01:30:44.000Z | /**
* Author: xiaoran
* Time: 2017-11-09 15:55
* Problem:
* 给你n个数,这n个数字的范围在0到n^2-1之间,请对这n个数排序,你能使用时间复杂度在O(n)时间的算法吗?
*
* 分析:
* 计数排序:O(n^2-1)
* 插入排序、选择排序:O(n*n)
* 归并排序、快速排序、堆排序:O(nlogn)
*
* 思考的艺术,我们知道两个重要的点,
* 比较排序的时间复杂度最优是O(logn),如果更优秀的方法,我们只能根据数据的范围
* 进行计数排序,那么我们的问题就是如何讲数据范围变成n。
* 要从n^2-1出发,... | 19.217391 | 59 | 0.531109 | xiaorancs |
c87418f9015157295076a8c57c6a644028956a46 | 17,341 | cpp | C++ | src/pgen/mignone_advection.cpp | kahoooo/athena-public | 583aee106677cba7fa5ea4e3689e2cfb81796e25 | [
"BSD-3-Clause"
] | 174 | 2016-11-30T01:20:14.000Z | 2022-02-22T16:23:55.000Z | src/pgen/mignone_advection.cpp | kahoooo/athena-public | 583aee106677cba7fa5ea4e3689e2cfb81796e25 | [
"BSD-3-Clause"
] | 74 | 2017-01-30T22:37:33.000Z | 2021-05-10T17:20:33.000Z | src/pgen/mignone_advection.cpp | kahoooo/athena-public | 583aee106677cba7fa5ea4e3689e2cfb81796e25 | [
"BSD-3-Clause"
] | 126 | 2016-12-08T14:03:22.000Z | 2022-03-31T06:01:59.000Z | //========================================================================================
// Athena++ astrophysical MHD code
// Copyright(C) 2014 James M. Stone <jmstone@princeton.edu> and other code contributors
// Licensed under the 3-clause BSD License, see LICENSE file for details
//===============================... | 40.995272 | 90 | 0.56427 | kahoooo |
c8742a5fe3d5ca3a85923be07fcd38f70d0e1f0c | 2,308 | cc | C++ | mindspore/ccsrc/minddata/dataset/kernels/image/random_crop_decode_resize_op.cc | dongkcs/mindspore | cd7df6dbf463ff3128e9181e9d0c779cecb81320 | [
"Apache-2.0"
] | 55 | 2020-12-17T10:26:06.000Z | 2022-03-28T07:18:26.000Z | mindspore/ccsrc/minddata/dataset/kernels/image/random_crop_decode_resize_op.cc | forwhat461/mindspore | 59a277756eb4faad9ac9afcc7fd526e8277d4994 | [
"Apache-2.0"
] | 1 | 2020-12-29T06:46:38.000Z | 2020-12-29T06:46:38.000Z | mindspore/ccsrc/minddata/dataset/kernels/image/random_crop_decode_resize_op.cc | forwhat461/mindspore | 59a277756eb4faad9ac9afcc7fd526e8277d4994 | [
"Apache-2.0"
] | 14 | 2021-01-29T02:39:47.000Z | 2022-03-23T05:00:26.000Z | /**
* Copyright 2019 Huawei Technologies Co., Ltd
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law... | 40.491228 | 113 | 0.70104 | dongkcs |
c8750cf267687ad12f169996e224dbf30401a981 | 202,600 | hpp | C++ | cisco-nx-os/ydk/models/cisco_nx_os/fragmented/Cisco_NX_OS_device_32.hpp | CiscoDevNet/ydk-cpp | ef7d75970f2ef1154100e0f7b0a2ee823609b481 | [
"ECL-2.0",
"Apache-2.0"
] | 17 | 2016-12-02T05:45:49.000Z | 2022-02-10T19:32:54.000Z | cisco-nx-os/ydk/models/cisco_nx_os/fragmented/Cisco_NX_OS_device_32.hpp | CiscoDevNet/ydk-cpp | ef7d75970f2ef1154100e0f7b0a2ee823609b481 | [
"ECL-2.0",
"Apache-2.0"
] | 2 | 2017-03-27T15:22:38.000Z | 2019-11-05T08:30:16.000Z | cisco-nx-os/ydk/models/cisco_nx_os/fragmented/Cisco_NX_OS_device_32.hpp | CiscoDevNet/ydk-cpp | ef7d75970f2ef1154100e0f7b0a2ee823609b481 | [
"ECL-2.0",
"Apache-2.0"
] | 11 | 2016-12-02T05:45:52.000Z | 2019-11-07T08:28:17.000Z | #ifndef _CISCO_NX_OS_DEVICE_32_
#define _CISCO_NX_OS_DEVICE_32_
#include <memory>
#include <vector>
#include <string>
#include <ydk/types.hpp>
#include <ydk/errors.hpp>
#include "Cisco_NX_OS_device_0.hpp"
#include "Cisco_NX_OS_device_29.hpp"
#include "Cisco_NX_OS_device_31.hpp"
namespace cisco_nx_os {
namespace Cisc... | 51.789366 | 187 | 0.698687 | CiscoDevNet |
c875f650f1b596fdc3c554286b2081c6b48ccb3b | 13,680 | cpp | C++ | drlvm/vm/jitrino/src/codegenerator/ipf/IpfLiveManager.cpp | sirinath/Harmony | 724deb045a85b722c961d8b5a83ac7a697319441 | [
"Apache-2.0"
] | 8 | 2015-11-04T06:06:35.000Z | 2021-07-04T13:47:36.000Z | drlvm/vm/jitrino/src/codegenerator/ipf/IpfLiveManager.cpp | sirinath/Harmony | 724deb045a85b722c961d8b5a83ac7a697319441 | [
"Apache-2.0"
] | 1 | 2021-10-17T13:07:28.000Z | 2021-10-17T13:07:28.000Z | drlvm/vm/jitrino/src/codegenerator/ipf/IpfLiveManager.cpp | sirinath/Harmony | 724deb045a85b722c961d8b5a83ac7a697319441 | [
"Apache-2.0"
] | 13 | 2015-11-27T03:14:50.000Z | 2022-02-26T15:12:20.000Z | /*
* Licensed to the Apache Software Foundation (ASF) under one or more
* contributor license agreements. See the NOTICE file distributed with
* this work for additional information regarding copyright ownership.
* The ASF licenses this file to You under the Apache License, Version 2.0
* (the "License"); you... | 41.204819 | 127 | 0.495687 | sirinath |
c87660a70d7e4877699ad5eec612ccb3fc093414 | 15,315 | hxx | C++ | planners/lapkt-public/include/aptk/gbfs_f_local/april_version/src/iw.hxx | miquelramirez/aamas18-planning-for-transparency | dff3e635102bf351906807c5181113fbf4b67083 | [
"MIT"
] | null | null | null | planners/lapkt-public/include/aptk/gbfs_f_local/april_version/src/iw.hxx | miquelramirez/aamas18-planning-for-transparency | dff3e635102bf351906807c5181113fbf4b67083 | [
"MIT"
] | null | null | null | planners/lapkt-public/include/aptk/gbfs_f_local/april_version/src/iw.hxx | miquelramirez/aamas18-planning-for-transparency | dff3e635102bf351906807c5181113fbf4b67083 | [
"MIT"
] | null | null | null | /*
Lightweight Automated Planning Toolkit
Copyright (C) 2012
Miquel Ramirez <miquel.ramirez@rmit.edu.au>
Nir Lipovetzky <nirlipo@gmail.com>
This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either vers... | 24.156151 | 252 | 0.587463 | miquelramirez |
c877fa444a3a164676cc295c9b060dd8da7b2770 | 6,040 | cpp | C++ | C45/contin.cpp | everyday-solution/ESolutions.C45 | 3285440e0b5812820c85f318c5d50585a7cee288 | [
"MIT"
] | null | null | null | C45/contin.cpp | everyday-solution/ESolutions.C45 | 3285440e0b5812820c85f318c5d50585a7cee288 | [
"MIT"
] | null | null | null | C45/contin.cpp | everyday-solution/ESolutions.C45 | 3285440e0b5812820c85f318c5d50585a7cee288 | [
"MIT"
] | null | null | null | /*************************************************************************/
/* */
/* Evaluation of a test on a continuous valued attribute */
/* ----------------------------------------------------- */
/* */
/***************************... | 25.166667 | 85 | 0.480629 | everyday-solution |
c87a86ece23cfd8bc7d069b7c4f76ada81064ed6 | 1,019 | hpp | C++ | ios/Pods/boost-for-react-native/boost/function_types/detail/encoding/undef.hpp | rudylee/expo | b3e65a7a5b205f14a3eb6cd6fa8d13c8d663b1cc | [
"Apache-2.0",
"MIT"
] | 8,805 | 2015-11-03T00:52:29.000Z | 2022-03-29T22:30:03.000Z | ios/Pods/boost-for-react-native/boost/function_types/detail/encoding/undef.hpp | rudylee/expo | b3e65a7a5b205f14a3eb6cd6fa8d13c8d663b1cc | [
"Apache-2.0",
"MIT"
] | 14,694 | 2015-02-24T15:13:42.000Z | 2022-03-31T13:16:45.000Z | ios/Pods/boost-for-react-native/boost/function_types/detail/encoding/undef.hpp | rudylee/expo | b3e65a7a5b205f14a3eb6cd6fa8d13c8d663b1cc | [
"Apache-2.0",
"MIT"
] | 1,329 | 2015-11-03T20:25:51.000Z | 2022-03-31T18:10:38.000Z |
// (C) Copyright Tobias Schwinger
//
// Use modification and distribution are subject to the boost Software License,
// Version 1.0. (See http://www.boost.org/LICENSE_1_0.txt).
//------------------------------------------------------------------------------
// no include guards, this file is intended for mul... | 26.128205 | 81 | 0.749755 | rudylee |
c87ab1bf12e789acfe15bfc687f2743a06515c8e | 12,253 | cpp | C++ | dpnp/backend/kernels/dpnp_krnl_manipulation.cpp | antonwolfy/dpnp | 7595c82a41bf5ab34cdefb3b5a9631f2365ac69a | [
"BSD-2-Clause"
] | null | null | null | dpnp/backend/kernels/dpnp_krnl_manipulation.cpp | antonwolfy/dpnp | 7595c82a41bf5ab34cdefb3b5a9631f2365ac69a | [
"BSD-2-Clause"
] | null | null | null | dpnp/backend/kernels/dpnp_krnl_manipulation.cpp | antonwolfy/dpnp | 7595c82a41bf5ab34cdefb3b5a9631f2365ac69a | [
"BSD-2-Clause"
] | null | null | null | //*****************************************************************************
// Copyright (c) 2016-2020, Intel Corporation
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are met:
// - Redistributio... | 45.720149 | 117 | 0.558149 | antonwolfy |
c87b9e09c7f32121e12d52365d377923ae6efe53 | 5,238 | cpp | C++ | tests/Unit/Time/StepChoosers/Test_PreventRapidIncrease.cpp | Ambrou/spectre | a819ebbcca607d8af9683db3683bea14bf4ac23c | [
"MIT"
] | null | null | null | tests/Unit/Time/StepChoosers/Test_PreventRapidIncrease.cpp | Ambrou/spectre | a819ebbcca607d8af9683db3683bea14bf4ac23c | [
"MIT"
] | null | null | null | tests/Unit/Time/StepChoosers/Test_PreventRapidIncrease.cpp | Ambrou/spectre | a819ebbcca607d8af9683db3683bea14bf4ac23c | [
"MIT"
] | 1 | 2019-01-03T21:47:04.000Z | 2019-01-03T21:47:04.000Z | // Distributed under the MIT License.
// See LICENSE.txt for details.
#include "Framework/TestingFramework.hpp"
#include <algorithm>
#include <cstddef>
#include <cstdint>
#include <initializer_list>
#include <limits>
#include <memory>
#include <utility>
#include <vector>
#include "DataStructures/DataBox/DataBox.hpp"... | 33.793548 | 80 | 0.641084 | Ambrou |
c87c06d8fae690cca8767232a46745d68877e113 | 2,849 | cpp | C++ | lib/boost_1.78.0/libs/spirit/classic/test/bug_000008.cpp | LaudateCorpus1/math | 990a66b3cccd27a5fd48626360bb91093a48278b | [
"BSD-3-Clause"
] | 1 | 2019-10-27T21:15:52.000Z | 2019-10-27T21:15:52.000Z | lib/boost_1.78.0/libs/spirit/classic/test/bug_000008.cpp | LaudateCorpus1/math | 990a66b3cccd27a5fd48626360bb91093a48278b | [
"BSD-3-Clause"
] | null | null | null | lib/boost_1.78.0/libs/spirit/classic/test/bug_000008.cpp | LaudateCorpus1/math | 990a66b3cccd27a5fd48626360bb91093a48278b | [
"BSD-3-Clause"
] | 1 | 2021-08-24T08:49:34.000Z | 2021-08-24T08:49:34.000Z | /*=============================================================================
Copyright (c) 2003 Martin Wille
http://spirit.sourceforge.net/
Use, modification and distribution is subject to the Boost Software
License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at
http://www.boost... | 24.560345 | 93 | 0.668656 | LaudateCorpus1 |
c87e78fba9dfd89a0e46d49b07ad4934f848357e | 5,382 | cpp | C++ | src/Core/examples/coro.cpp | mrk-andreev/ClickHouse | a36f05d6b892aa714c02661c87e2c28f2239020d | [
"Apache-2.0"
] | 2 | 2022-01-10T04:50:22.000Z | 2022-01-10T04:51:42.000Z | src/Core/examples/coro.cpp | mrk-andreev/ClickHouse | a36f05d6b892aa714c02661c87e2c28f2239020d | [
"Apache-2.0"
] | 16 | 2022-02-14T15:53:29.000Z | 2022-03-25T18:39:16.000Z | src/Core/examples/coro.cpp | Vector-Similarity-Search-for-ClickHouse/ClickHouse | 996d838ca33f1156a1c6d0868140bab23f8b6155 | [
"Apache-2.0"
] | 1 | 2020-05-28T07:29:23.000Z | 2020-05-28T07:29:23.000Z | #include <cassert>
#include <iostream>
#include <string>
#include <optional>
#include <Common/Exception.h>
#include <Common/logger_useful.h>
#include <Poco/ConsoleChannel.h>
#include <Poco/Logger.h>
#include <Poco/AutoPtr.h>
#if defined(__clang__)
#include <experimental/coroutine>
namespace std
{
using namespace... | 28.326316 | 118 | 0.582126 | mrk-andreev |
c8810fb05be038ac190400a166720131d636b6f9 | 4,560 | cpp | C++ | src/NovelRT.Interop/DotNet/NrtRuntimeService.cpp | chococookies131/NovelRT | 1e9b72abf53391a9d86f7fd3e171599e820de2a2 | [
"MIT"
] | null | null | null | src/NovelRT.Interop/DotNet/NrtRuntimeService.cpp | chococookies131/NovelRT | 1e9b72abf53391a9d86f7fd3e171599e820de2a2 | [
"MIT"
] | null | null | null | src/NovelRT.Interop/DotNet/NrtRuntimeService.cpp | chococookies131/NovelRT | 1e9b72abf53391a9d86f7fd3e171599e820de2a2 | [
"MIT"
] | null | null | null | // Copyright © Matt Jones and Contributors. Licensed under the MIT Licence (MIT). See LICENCE.md in the repository root for more information.
#include <NovelRT.Interop/NrtInteropErrorHandlingInternal.h>
#include <NovelRT.Interop/NrtInteropUtils.h>
#include <NovelRT.Interop/DotNet/NrtRuntimeService.h>
#include <NovelRT... | 31.888112 | 141 | 0.745175 | chococookies131 |
c8815f45a9da1dc0e19958879c39e4ad05810e1c | 56,801 | cpp | C++ | Source/VoxelGraphEditor/Private/VoxelGraphEditorToolkit.cpp | SolarStormInteractive/VoxelPlugin | b0b8a1838262227fa586fbcb1b46a6184cdf1e8c | [
"MIT"
] | null | null | null | Source/VoxelGraphEditor/Private/VoxelGraphEditorToolkit.cpp | SolarStormInteractive/VoxelPlugin | b0b8a1838262227fa586fbcb1b46a6184cdf1e8c | [
"MIT"
] | null | null | null | Source/VoxelGraphEditor/Private/VoxelGraphEditorToolkit.cpp | SolarStormInteractive/VoxelPlugin | b0b8a1838262227fa586fbcb1b46a6184cdf1e8c | [
"MIT"
] | null | null | null | // Copyright 2020 Phyronnaz
#include "VoxelGraphEditorToolkit.h"
#include "VoxelGraphEditorUtilities.h"
#include "VoxelGraphGenerator.h"
#include "VoxelGraphShortcuts.h"
#include "VoxelGraphPreviewSettings.h"
#include "VoxelGraphImportExposedVariablesValues.h"
#include "VoxelGraphSchema.h"
#include "VoxelNode... | 32.383694 | 190 | 0.706678 | SolarStormInteractive |
c88294db1bde4da965ba9b8371eadae98f86936a | 78,479 | hpp | C++ | src/msgpack/preprocessor/repetition/detail/dmc/for.hpp | Kronuz/Xapiand | a71570859dcfc9f48090d845053f359b07f4f78c | [
"MIT"
] | 370 | 2016-03-14T12:19:08.000Z | 2022-03-25T02:07:29.000Z | src/msgpack/preprocessor/repetition/detail/dmc/for.hpp | puer99miss/Xapiand | 480f312709d40e2b1deb244ff0761b79846ed608 | [
"MIT"
] | 34 | 2015-11-30T19:06:40.000Z | 2022-02-26T03:46:58.000Z | src/msgpack/preprocessor/repetition/detail/dmc/for.hpp | puer99miss/Xapiand | 480f312709d40e2b1deb244ff0761b79846ed608 | [
"MIT"
] | 31 | 2015-02-13T22:27:34.000Z | 2022-03-25T02:07:34.000Z | # /* Copyright (C) 2001
# * Housemarque Oy
# * http://www.housemarque.com
# *
# * Distributed under the Boost Software License, Version 1.0. (See
# * accompanying file LICENSE_1_0.txt or copy at
# * http://www.boost.org/LICENSE_1_0.txt)
# */
#
# /* Revised by Paul Mensonides (2002) */
#
# /* See http://www.boost... | 146.143389 | 203 | 0.739612 | Kronuz |
c8842edb55f427acc1ab99f1f35fad7930b7b61c | 2,548 | hpp | C++ | include/System/DefaultBinder_BinderState.hpp | darknight1050/BeatSaber-Quest-Codegen | a6eeecc3f0e8f6079630f9a9a72b3121ac7b2032 | [
"Unlicense"
] | null | null | null | include/System/DefaultBinder_BinderState.hpp | darknight1050/BeatSaber-Quest-Codegen | a6eeecc3f0e8f6079630f9a9a72b3121ac7b2032 | [
"Unlicense"
] | null | null | null | include/System/DefaultBinder_BinderState.hpp | darknight1050/BeatSaber-Quest-Codegen | a6eeecc3f0e8f6079630f9a9a72b3121ac7b2032 | [
"Unlicense"
] | null | null | null | // Autogenerated from CppHeaderCreator
// Created by Sc2ad
// =========================================================================
#pragma once
// Begin includes
#include "extern/beatsaber-hook/shared/utils/typedefs.h"
// Including type: System.DefaultBinder
#include "System/DefaultBinder.hpp"
#include "ex... | 47.185185 | 202 | 0.69741 | darknight1050 |
c8858c981a72319b1427b553f4d4c4bdbaf0ee10 | 3,193 | ipp | C++ | deps/boost/include/boost/beast/http/impl/error.ipp | kindlychung/mediasoup-sfu-cpp | f69d2f48f7edbf4f0c57244280a47bea985f39cf | [
"Apache-2.0"
] | 80 | 2021-09-07T12:44:32.000Z | 2022-03-29T01:22:19.000Z | deps/boost/include/boost/beast/http/impl/error.ipp | kindlychung/mediasoup-sfu-cpp | f69d2f48f7edbf4f0c57244280a47bea985f39cf | [
"Apache-2.0"
] | 2 | 2021-12-23T02:49:42.000Z | 2022-02-15T05:28:24.000Z | deps/boost/include/boost/beast/http/impl/error.ipp | kindlychung/mediasoup-sfu-cpp | f69d2f48f7edbf4f0c57244280a47bea985f39cf | [
"Apache-2.0"
] | 25 | 2021-09-14T06:24:25.000Z | 2022-03-20T06:55:07.000Z | //
// Copyright (c) 2016-2019 Vinnie Falco (vinnie dot falco at gmail dot com)
//
// Distributed under the Boost Software License, Version 1.0. (See accompanying
// file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
//
// Official repository: https://github.com/boostorg/beast
//
#ifndef BOO... | 30.122642 | 80 | 0.630755 | kindlychung |
c8861db6cf5d83788c484d54a06f58c9bd355c3a | 13,311 | cpp | C++ | third_party/skia_m84/third_party/externals/angle2/src/tests/gl_tests/LinkAndRelinkTest.cpp | kniefliu/WindowsSamples | c841268ef4a0f1c6f89b8e95bf68058ea2548394 | [
"MIT"
] | 6 | 2021-07-05T16:09:39.000Z | 2022-03-06T22:44:42.000Z | third_party/skia_m84/third_party/externals/angle2/src/tests/gl_tests/LinkAndRelinkTest.cpp | kniefliu/WindowsSamples | c841268ef4a0f1c6f89b8e95bf68058ea2548394 | [
"MIT"
] | 7 | 2022-03-15T13:25:39.000Z | 2022-03-15T13:25:44.000Z | third_party/skia_m84/third_party/externals/angle2/src/tests/gl_tests/LinkAndRelinkTest.cpp | kniefliu/WindowsSamples | c841268ef4a0f1c6f89b8e95bf68058ea2548394 | [
"MIT"
] | null | null | null | //
// Copyright 2017 The ANGLE Project Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
//
// LinkAndRelinkFailureTest:
// Link and relink failure tests for rendering pipeline and compute pipeline.
#include <vector>
#include "test_u... | 29.64588 | 84 | 0.718729 | kniefliu |
c888c4fabe8a4b64f3d91a539000e5694a44e475 | 11,426 | cpp | C++ | src/gtirb_pprinter/Mips32PrettyPrinter.cpp | GrammaTech/gtirb-pprinter | d3c7063ea0a6a4edefa6be76bf4d56527ba63855 | [
"MIT"
] | 36 | 2018-11-09T15:57:13.000Z | 2022-03-02T20:07:56.000Z | src/gtirb_pprinter/Mips32PrettyPrinter.cpp | GrammaTech/gtirb-pprinter | d3c7063ea0a6a4edefa6be76bf4d56527ba63855 | [
"MIT"
] | 10 | 2020-04-14T03:55:14.000Z | 2022-02-21T19:39:27.000Z | src/gtirb_pprinter/Mips32PrettyPrinter.cpp | GrammaTech/gtirb-pprinter | d3c7063ea0a6a4edefa6be76bf4d56527ba63855 | [
"MIT"
] | 14 | 2019-04-17T21:11:39.000Z | 2022-03-02T20:07:58.000Z | //===- Mips32PrettyPrinter.cpp ----------------------------------*- C++ -*-===//
//
// Copyright (c) 2020 GrammaTech, Inc.
//
// This code is licensed under the MIT license. See the LICENSE file in the
// project root for license terms.
//
// This project is sponsored by the Office of Naval Research, One Liberty
//... | 36.158228 | 80 | 0.628216 | GrammaTech |
c888d8434dbe6267c3226793419b3fb3fcfc39e3 | 3,125 | cpp | C++ | Linked List/Sorting a LL.cpp | hidayat7z/Data-Structures-and-Algorithms | b78fc9c09b55f6ce9e92edeb48b5069792c4341b | [
"MIT"
] | 22 | 2020-09-13T15:12:50.000Z | 2021-01-29T08:29:57.000Z | Linked List/Sorting a LL.cpp | hidayat7z/Data-Structures-and-Algorithms | b78fc9c09b55f6ce9e92edeb48b5069792c4341b | [
"MIT"
] | null | null | null | Linked List/Sorting a LL.cpp | hidayat7z/Data-Structures-and-Algorithms | b78fc9c09b55f6ce9e92edeb48b5069792c4341b | [
"MIT"
] | 6 | 2020-09-13T15:34:38.000Z | 2021-01-29T08:30:01.000Z | #include<stdio.h>
#include<stdlib.h>
struct node
{
int data;
struct node *next;
};
struct node *start1= NULL;
struct node *createList(struct node*,int);
void display(struct node*);
struct node *swap(struct node*, struct node*);
struct node *sort(int);
int main()
{
int n,i,val;
printf("Ente... | 15.625 | 83 | 0.55008 | hidayat7z |
c8897da2e04436310e0ca7714bd69723a12ed836 | 3,772 | cpp | C++ | projects/robots/robotis/darwin-op/transfer/src/PositionSensor.cpp | yjf18340/webots | 60d441c362031ab8fde120cc0cd97bdb1a31a3d5 | [
"Apache-2.0"
] | 1 | 2019-11-13T08:12:02.000Z | 2019-11-13T08:12:02.000Z | projects/robots/robotis/darwin-op/transfer/src/PositionSensor.cpp | chinakwy/webots | 7c35a359848bafe81fe0229ac2ed587528f4c73e | [
"Apache-2.0"
] | null | null | null | projects/robots/robotis/darwin-op/transfer/src/PositionSensor.cpp | chinakwy/webots | 7c35a359848bafe81fe0229ac2ed587528f4c73e | [
"Apache-2.0"
] | 1 | 2020-09-25T02:01:45.000Z | 2020-09-25T02:01:45.000Z | // Copyright 1996-2019 Cyberbotics Ltd.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agr... | 32.239316 | 75 | 0.724284 | yjf18340 |
c889a7bba34b62a1cb1e29fb75ab13cb744cabce | 11,855 | cpp | C++ | phaser.cpp | panguangze/SpecHap | f2b44d2dda5d76da062162005d572664ae8090ae | [
"MIT"
] | null | null | null | phaser.cpp | panguangze/SpecHap | f2b44d2dda5d76da062162005d572664ae8090ae | [
"MIT"
] | null | null | null | phaser.cpp | panguangze/SpecHap | f2b44d2dda5d76da062162005d572664ae8090ae | [
"MIT"
] | null | null | null | //
// Created by yyh on 3/4/2019.
//
#include "phaser.h"
#include "htslib/vcf.h"
#include "type.h"
#include "util.h"
#include <iostream>
#include <cstdlib>
#include <unordered_map>
// TODO clarify between variant count and block count
Phaser::Phaser(const std::string &fnvcf, const std::string &fnout, std::vector<std... | 31.613333 | 128 | 0.55639 | panguangze |
c889ab8f1ce62c843c8327d8a7d1e33e95100dfa | 176 | cpp | C++ | src/core/utils/build/external_template.cpp | lii-enac/djnn-cpp | f27c5ba3186186ee22c93ae91c16063556e929b6 | [
"BSD-2-Clause"
] | 4 | 2018-09-11T14:27:57.000Z | 2019-12-16T21:06:26.000Z | src/core/utils/build/external_template.cpp | lii-enac/djnn-cpp | f27c5ba3186186ee22c93ae91c16063556e929b6 | [
"BSD-2-Clause"
] | null | null | null | src/core/utils/build/external_template.cpp | lii-enac/djnn-cpp | f27c5ba3186186ee22c93ae91c16063556e929b6 | [
"BSD-2-Clause"
] | 2 | 2018-06-11T14:15:30.000Z | 2019-01-09T12:23:35.000Z | #include "precompiled.h"
template class djnnstl::basic_string<char>;
template class djnn::map<djnn::string, djnn::CoreProcess*>;
template class djnn::vector<djnn::Coupling*>;
| 29.333333 | 59 | 0.767045 | lii-enac |
c88b2efea517783253c22a339fd5a3258d1421cb | 42,719 | cpp | C++ | source/d3d12/reshade_api_device.cpp | chrismile/reshade | 8c12ce8aee738b2639126e3b6ed259fd9cbeae9f | [
"BSD-3-Clause"
] | null | null | null | source/d3d12/reshade_api_device.cpp | chrismile/reshade | 8c12ce8aee738b2639126e3b6ed259fd9cbeae9f | [
"BSD-3-Clause"
] | null | null | null | source/d3d12/reshade_api_device.cpp | chrismile/reshade | 8c12ce8aee738b2639126e3b6ed259fd9cbeae9f | [
"BSD-3-Clause"
] | null | null | null | /*
* Copyright (C) 2021 Patrick Mours. All rights reserved.
* License: https://github.com/crosire/reshade#license
*/
#include "dll_log.hpp"
#include "dll_resources.hpp"
#include "reshade_api_device.hpp"
#include "reshade_api_command_queue.hpp"
#include "reshade_api_type_utils.hpp"
const GUID reshade::d3d12::pipeli... | 41.59591 | 230 | 0.780894 | chrismile |
c88c6c180163db664d0dde6c813e63e1ccbbb6b0 | 20,479 | cpp | C++ | android/android_23/frameworks/base/media/libstagefright/mpeg2ts/ATSParser.cpp | yakuizhao/intel-vaapi-driver | b2bb0383352694941826543a171b557efac2219b | [
"MIT"
] | null | null | null | android/android_23/frameworks/base/media/libstagefright/mpeg2ts/ATSParser.cpp | yakuizhao/intel-vaapi-driver | b2bb0383352694941826543a171b557efac2219b | [
"MIT"
] | null | null | null | android/android_23/frameworks/base/media/libstagefright/mpeg2ts/ATSParser.cpp | yakuizhao/intel-vaapi-driver | b2bb0383352694941826543a171b557efac2219b | [
"MIT"
] | null | null | null | /*
* Copyright (C) 2010 The Android Open Source Project
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by app... | 29.940058 | 80 | 0.603399 | yakuizhao |
c8913671a099e4122e485136541322089eb68915 | 729 | cpp | C++ | LeetCode/search-BST.cpp | abusomani/DS-Algo | b81b592b4ccb6c1c8a1c5275f1411ba4e91977ba | [
"Unlicense"
] | null | null | null | LeetCode/search-BST.cpp | abusomani/DS-Algo | b81b592b4ccb6c1c8a1c5275f1411ba4e91977ba | [
"Unlicense"
] | null | null | null | LeetCode/search-BST.cpp | abusomani/DS-Algo | b81b592b4ccb6c1c8a1c5275f1411ba4e91977ba | [
"Unlicense"
] | null | null | null | //Sometimes I feel like giving up, then I remember I have a lot of motherfuckers to prove wrong!
//@BEGIN OF SOURCE CODE ( By Abhishek Somani)
#include <bits/stdc++.h>
using namespace std;
// Definition for a binary tree node.
struct TreeNode
{
int val;
TreeNode *left;
TreeNode *right;
TreeNode(int x) ... | 23.516129 | 96 | 0.565158 | abusomani |
c891a4a6ebd43d3530ea74f4aec70387ce79630e | 8,244 | cpp | C++ | extensions/openpower-pels/pldm_interface.cpp | Alpana07/phosphor-logging | 1be39849bd974c2f7df7fa932edcd7f71a2c6d59 | [
"Apache-2.0"
] | 5 | 2017-12-01T19:34:13.000Z | 2020-12-29T10:50:32.000Z | extensions/openpower-pels/pldm_interface.cpp | Alpana07/phosphor-logging | 1be39849bd974c2f7df7fa932edcd7f71a2c6d59 | [
"Apache-2.0"
] | 26 | 2017-02-02T08:20:10.000Z | 2021-11-16T18:28:44.000Z | extensions/openpower-pels/pldm_interface.cpp | Alpana07/phosphor-logging | 1be39849bd974c2f7df7fa932edcd7f71a2c6d59 | [
"Apache-2.0"
] | 28 | 2016-07-20T16:46:54.000Z | 2022-03-16T11:20:03.000Z | /**
* Copyright © 2019 IBM Corporation
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agr... | 22.963788 | 80 | 0.574842 | Alpana07 |
c89241cd3ffc7e58eaa6ca180033c710a644f2e4 | 3,641 | cpp | C++ | examples/rgb2hsv.cpp | Bensuo/visioncpp | 8b4233809fbc9f0ad2ee59ec8dfe6de078e44777 | [
"Apache-2.0"
] | 156 | 2016-09-15T13:05:21.000Z | 2022-03-04T01:41:39.000Z | examples/rgb2hsv.cpp | Bensuo/visioncpp | 8b4233809fbc9f0ad2ee59ec8dfe6de078e44777 | [
"Apache-2.0"
] | 24 | 2016-09-20T11:25:23.000Z | 2022-02-01T02:20:27.000Z | examples/rgb2hsv.cpp | Bensuo/visioncpp | 8b4233809fbc9f0ad2ee59ec8dfe6de078e44777 | [
"Apache-2.0"
] | 58 | 2016-09-15T14:08:28.000Z | 2022-02-28T04:55:55.000Z | // This file is part of VisionCpp, a lightweight C++ template library
// for computer vision and image processing.
//
// Copyright (C) 2016 Codeplay Software Limited. All Rights Reserved.
//
// Contact: visioncpp@codeplay.com
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this ... | 39.150538 | 80 | 0.650096 | Bensuo |
c892be1378236fc83bf692cce5dc2ea732febb8a | 2,640 | cpp | C++ | Plugin~/Src/MeshSync/SceneGraph/msAsset.cpp | Hengle/MeshSync | 720559dfa9350815ded44daafebd198019121f1a | [
"Apache-2.0"
] | 2 | 2021-06-18T23:32:57.000Z | 2021-09-01T02:10:04.000Z | Plugin~/Src/MeshSync/SceneGraph/msAsset.cpp | artigee/MeshSync | 4fa8ef749c934661951b775db239878bcfb06431 | [
"Apache-2.0"
] | null | null | null | Plugin~/Src/MeshSync/SceneGraph/msAsset.cpp | artigee/MeshSync | 4fa8ef749c934661951b775db239878bcfb06431 | [
"Apache-2.0"
] | 1 | 2020-04-10T01:08:38.000Z | 2020-04-10T01:08:38.000Z | #include "pch.h"
#include "msAsset.h"
#include "msMisc.h"
#include "msAnimation.h"
#include "msTexture.h"
#include "msMaterial.h"
#include "msAudio.h"
namespace ms {
// Asset
#define EachMember(F) F(name) F(id)
std::shared_ptr<Asset> Asset::create(std::istream& is)
{
int type;
read(is, type);
std::sha... | 17.718121 | 68 | 0.642424 | Hengle |
c895ab6fd34aaee7f40eec25e6fd5f3c3c8fff75 | 7,678 | hpp | C++ | external/mysql_connector/extlib/yassl/taocrypt/include/rsa.hpp | wangsun1983/Obotcha | 2464e53599305703f5150df72bf73579a39d8ef4 | [
"MIT"
] | 27 | 2019-04-27T00:51:22.000Z | 2022-03-30T04:05:44.000Z | external/mysql_connector/extlib/yassl/taocrypt/include/rsa.hpp | wangsun1983/Obotcha | 2464e53599305703f5150df72bf73579a39d8ef4 | [
"MIT"
] | 9 | 2020-05-03T12:17:50.000Z | 2021-10-15T02:18:47.000Z | external/mysql_connector/extlib/yassl/taocrypt/include/rsa.hpp | wangsun1983/Obotcha | 2464e53599305703f5150df72bf73579a39d8ef4 | [
"MIT"
] | 1 | 2019-04-16T01:45:36.000Z | 2019-04-16T01:45:36.000Z | /*
Copyright (C) 2000-2007 MySQL AB
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; version 2 of the License.
This program is distributed in the hope that it will be useful,
but WI... | 30.589641 | 78 | 0.669966 | wangsun1983 |
c89881ac919d7a172dcf68afd9e39961f89368ac | 9,654 | cpp | C++ | src/peco/task/impl/loopimpl.cpp | littlepush/libpeco | c0ca92ddb7a70cd8183ade1ee0ec57fd534e280e | [
"MIT"
] | 1 | 2020-04-14T06:31:56.000Z | 2020-04-14T06:31:56.000Z | src/peco/task/impl/loopimpl.cpp | littlepush/libpeco | c0ca92ddb7a70cd8183ade1ee0ec57fd534e280e | [
"MIT"
] | null | null | null | src/peco/task/impl/loopimpl.cpp | littlepush/libpeco | c0ca92ddb7a70cd8183ade1ee0ec57fd534e280e | [
"MIT"
] | null | null | null | /*
loopimpl.cpp
libpeco
2022-02-12
Push Chen
*/
/*
MIT License
Copyright (c) 2019 Push Chen
Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without... | 30.647619 | 97 | 0.672985 | littlepush |
c899ebe6741ccb7aa2fd460ce4e7e00cf2e2c83b | 970 | cpp | C++ | src/mpu6050.cpp | AITT-VN/xcontroller_arduino_lib | 6a0b7234848bc062361110cb12db10467dc0e3a8 | [
"Apache-2.0"
] | null | null | null | src/mpu6050.cpp | AITT-VN/xcontroller_arduino_lib | 6a0b7234848bc062361110cb12db10467dc0e3a8 | [
"Apache-2.0"
] | null | null | null | src/mpu6050.cpp | AITT-VN/xcontroller_arduino_lib | 6a0b7234848bc062361110cb12db10467dc0e3a8 | [
"Apache-2.0"
] | null | null | null | #include "mpu6050.h"
void MPU6050::begin(){
Wire.begin();
delay(10);
Wire.beginTransmission(ADDR_MPU6050);
Wire.write(0x1b);
Wire.write(0b11000);
Wire.endTransmission();
Wire.beginTransmission(ADDR_MPU6050);
Wire.write(0x6b);
Wire.write(0x01);
Wire.endTransmission(... | 20.208333 | 45 | 0.654639 | AITT-VN |
c89c334baa1f7025bf4ac08852dc2cd7505e1d7f | 444 | cc | C++ | networking/packet_handlers/unknown_packet_handler.cc | RikoOphorst/Tremble | 650fa53402f9c6114642e0cc8515b2ed517d40d6 | [
"MIT"
] | 1 | 2021-10-17T06:41:46.000Z | 2021-10-17T06:41:46.000Z | networking/packet_handlers/unknown_packet_handler.cc | RikoOphorst/Tremble | 650fa53402f9c6114642e0cc8515b2ed517d40d6 | [
"MIT"
] | null | null | null | networking/packet_handlers/unknown_packet_handler.cc | RikoOphorst/Tremble | 650fa53402f9c6114642e0cc8515b2ed517d40d6 | [
"MIT"
] | null | null | null | //#include "unknown_packet_handler.h"
//#include <iostream>
//
//using namespace networking;
//
//UnknownPacketHandler::UnknownPacketHandler(NetworkController & net_controller) : IPacketHandler(net_controller)
//{
//}
//
//UnknownPacketHandler::~UnknownPacketHandler()
//{
//}
//
//void UnknownPacketHandler::Handle(int ... | 24.666667 | 113 | 0.707207 | RikoOphorst |
c89d7273fe025a63614ca62ef15a964207d7bfae | 9,037 | cxx | C++ | Widgets/vtkAffineWidget.cxx | Lin1225/vtk_v5.10.0 | b54ac74f4716572862365fbff28cd0ecb8d08c3d | [
"BSD-3-Clause"
] | 2 | 2015-07-11T13:30:23.000Z | 2017-12-19T05:23:38.000Z | Widgets/vtkAffineWidget.cxx | Armand0s/homemade_vtk | 6bc7b595a4a7f86e8fa969d067360450fa4e0a6a | [
"BSD-3-Clause"
] | null | null | null | Widgets/vtkAffineWidget.cxx | Armand0s/homemade_vtk | 6bc7b595a4a7f86e8fa969d067360450fa4e0a6a | [
"BSD-3-Clause"
] | 5 | 2015-03-23T21:13:19.000Z | 2022-01-03T11:15:39.000Z | /*=========================================================================
Program: Visualization Toolkit
Module: vtkAffineWidget.cxx
Copyright (c) Ken Martin, Will Schroeder, Bill Lorensen
All rights reserved.
See Copyright.txt or http://www.kitware.com/Copyright.htm for details.
This software ... | 36.439516 | 88 | 0.626314 | Lin1225 |
c89dbc50114c4cd8bba606b545ad161e010c627c | 181,718 | cpp | C++ | smartag-20180313/src/smartag_20180313.cpp | aliyun/alibabacloud-cpp-sdk | 0e7c0576abcd4ef1aef07d714b92654deb713c36 | [
"Apache-2.0"
] | 5 | 2021-02-01T03:20:23.000Z | 2022-01-28T02:13:49.000Z | smartag-20180313/src/smartag_20180313.cpp | aliyun/alibabacloud-cpp-sdk | 0e7c0576abcd4ef1aef07d714b92654deb713c36 | [
"Apache-2.0"
] | 4 | 2021-05-03T08:34:12.000Z | 2022-01-28T02:13:33.000Z | smartag-20180313/src/smartag_20180313.cpp | aliyun/alibabacloud-cpp-sdk | 0e7c0576abcd4ef1aef07d714b92654deb713c36 | [
"Apache-2.0"
] | 5 | 2021-04-02T02:59:04.000Z | 2022-02-24T02:33:44.000Z | // This file is auto-generated, don't edit it. Thanks.
#include <alibabacloud/smartag_20180313.hpp>
#include <alibabacloud/endpoint_util.hpp>
#include <alibabacloud/open_api.hpp>
#include <boost/any.hpp>
#include <boost/throw_exception.hpp>
#include <darabonba/core.hpp>
#include <darabonba/util.hpp>
#include <iostream... | 79.387505 | 303 | 0.816413 | aliyun |
c8a3fe8757fd21ba2c56f472f3a0a54a86a4fefd | 1,219 | cpp | C++ | source/SoloFeature.cpp | rammid1189/STAR | 75461e7e1a4a315e6dde87c85317e3f67e8d7a98 | [
"MIT"
] | 1 | 2020-04-29T12:37:20.000Z | 2020-04-29T12:37:20.000Z | source/SoloFeature.cpp | alexey0308/STAR | eb9b28f869ba82cdfcc45c6f76c53513e25f1fcc | [
"MIT"
] | null | null | null | source/SoloFeature.cpp | alexey0308/STAR | eb9b28f869ba82cdfcc45c6f76c53513e25f1fcc | [
"MIT"
] | null | null | null | #include "SoloFeature.h"
#include "streamFuns.h"
#include "ErrorWarning.h"
SoloFeature::SoloFeature(int32 feTy, Parameters &Pin, Transcriptome &inTrans, SoloReadBarcode *readBarSumIn, SoloFeature **soloFeatAll)
:featureType(feTy), P(Pin), Trans(inTrans), soloFeatAll(soloFeatAll), pSolo(P.pSolo), readBarSum... | 43.535714 | 135 | 0.707957 | rammid1189 |
c8a4a6baccd1672f48a44dfe5c983638c38a4f73 | 104,321 | cc | C++ | third_party/cld/encodings/compact_lang_det/compact_lang_det_impl.cc | kjthegod/chromium | cf940f7f418436b77e15b1ea23e6fa100ca1c91a | [
"BSD-3-Clause-No-Nuclear-License-2014",
"BSD-3-Clause"
] | 231 | 2015-01-08T09:04:44.000Z | 2021-12-30T03:03:10.000Z | third_party/cld/encodings/compact_lang_det/compact_lang_det_impl.cc | j4ckfrost/android_external_chromium_org | a1a3dad8b08d1fcf6b6b36c267158ed63217c780 | [
"BSD-3-Clause-No-Nuclear-License-2014",
"BSD-3-Clause"
] | 1 | 2017-02-14T21:55:58.000Z | 2017-02-14T21:55:58.000Z | third_party/cld/encodings/compact_lang_det/compact_lang_det_impl.cc | j4ckfrost/android_external_chromium_org | a1a3dad8b08d1fcf6b6b36c267158ed63217c780 | [
"BSD-3-Clause-No-Nuclear-License-2014",
"BSD-3-Clause"
] | 268 | 2015-01-21T05:53:28.000Z | 2022-03-25T22:09:01.000Z | // Copyright (c) 2009 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
#include <stdio.h>
#include <string.h>
//#include <sys/time.h> // for gettimeofday
#include <string>
#include "encoding... | 40.670955 | 96 | 0.631158 | kjthegod |
c8a655c12bd3b36faee28e863411eb542ccc005b | 16,144 | cpp | C++ | pehlaschool/Classes/Games/LRComprehension/LRDividedTypeFillTheBlanks/LRDividedTypeFillTheBlanksScene.cpp | maqsoftware/Pehla-School-Hindi | 61aeae0f1d91952b44eaeaff5d2f6ec1d5aa3c43 | [
"Apache-2.0"
] | 2 | 2019-11-06T23:06:22.000Z | 2019-12-08T09:10:19.000Z | pehlaschool/Classes/Games/LRComprehension/LRDividedTypeFillTheBlanks/LRDividedTypeFillTheBlanksScene.cpp | maqsoftware/GLEXP-Team-KitkitSchool-Hindi | 61aeae0f1d91952b44eaeaff5d2f6ec1d5aa3c43 | [
"Apache-2.0"
] | 123 | 2019-05-28T14:03:04.000Z | 2019-07-12T04:23:26.000Z | pehlaschool/Classes/Games/LRComprehension/LRDividedTypeFillTheBlanks/LRDividedTypeFillTheBlanksScene.cpp | maqsoftware/Pehla-School-Hindi | 61aeae0f1d91952b44eaeaff5d2f6ec1d5aa3c43 | [
"Apache-2.0"
] | 5 | 2019-07-25T09:46:07.000Z | 2020-12-22T06:37:40.000Z | //
// FillTheBlanksScene.cpp
// PehlaSchool
//
// Created by timewalker on 13/12/2016.
//
//
#include "LRDividedTypeFillTheBlanksHeader.hpp"
#include "LRDividedTypeFillTheBlanksScene.hpp"
#include "Managers/StrictLogManager.h"
namespace
{
const bool bDebug = false;
const Size gameSize = Size(2560, 180... | 32.352705 | 176 | 0.608214 | maqsoftware |
c8a6c5d326cd4726e9f91cbe381d4dda1c4d47e8 | 3,020 | cpp | C++ | alignmut/restable.cpp | sferanchuk/tbev | 71e62ae093719aa0e0de4708e87e589129b44f96 | [
"MIT"
] | null | null | null | alignmut/restable.cpp | sferanchuk/tbev | 71e62ae093719aa0e0de4708e87e589129b44f96 | [
"MIT"
] | null | null | null | alignmut/restable.cpp | sferanchuk/tbev | 71e62ae093719aa0e0de4708e87e589129b44f96 | [
"MIT"
] | null | null | null |
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <string>
#include <vector>
#include <set>
#include <map>
using namespace std;
int main( int argc, char **argv )
{
vector< vector< string > > table;
vector<int> mut;
vector< string > ids;
vector< map<string,int> > other;
vector<int> lcvec;
int... | 29.320388 | 147 | 0.527152 | sferanchuk |
c8a709c0f8f841becae522a2b9d2e2fec7be4345 | 5,900 | cpp | C++ | c-src/Fl_Paged_DeviceC.cpp | ericu/fltkhs | 3ca521ca30d51a84f8ec87938932f2ce5af8a7c0 | [
"MIT"
] | 222 | 2015-01-11T19:01:16.000Z | 2022-03-25T14:47:26.000Z | c-src/Fl_Paged_DeviceC.cpp | ericu/fltkhs | 3ca521ca30d51a84f8ec87938932f2ce5af8a7c0 | [
"MIT"
] | 143 | 2015-01-13T19:08:33.000Z | 2021-10-10T20:43:46.000Z | c-src/Fl_Paged_DeviceC.cpp | ericu/fltkhs | 3ca521ca30d51a84f8ec87938932f2ce5af8a7c0 | [
"MIT"
] | 36 | 2015-01-14T15:30:18.000Z | 2021-08-11T13:04:28.000Z | #include "Fl_Paged_DeviceC.h"
#ifdef __cplusplus
EXPORT {
#endif
FL_EXPORT_C(void,Fl_Paged_Device_set_current)(fl_Paged_Device paged_device){
return (static_cast<Fl_Paged_Device*>(paged_device))->set_current();
}
FL_EXPORT_C(fl_Surface_Device,Fl_Paged_Device_surface)(){
return (fl_Surface_Device)Fl_Surfac... | 62.105263 | 160 | 0.80322 | ericu |
c8a7b8d8387e470634834f5a8a8b65415c370361 | 1,598 | hpp | C++ | source/boost/simd/arch/common/generic/function/genmask.hpp | chronos38/low_latency_demo | de0d0d3dcebff23ba77c06c6c368b9d1c3d2c648 | [
"MIT"
] | 3 | 2017-11-18T18:23:16.000Z | 2019-02-15T12:41:24.000Z | include/boost/simd/arch/common/generic/function/genmask.hpp | dendisuhubdy/boost.simd | 7630b1c1ffbd0300c100885b89ff78c2d579a24c | [
"BSL-1.0"
] | null | null | null | include/boost/simd/arch/common/generic/function/genmask.hpp | dendisuhubdy/boost.simd | 7630b1c1ffbd0300c100885b89ff78c2d579a24c | [
"BSL-1.0"
] | 1 | 2019-04-11T20:18:39.000Z | 2019-04-11T20:18:39.000Z | //==================================================================================================
/*!
@file
@copyright 2016 NumScale SAS
Distributed under the Boost Software License, Version 1.0.
(See accompanying file LICENSE.md or copy at http://boost.org/LICENSE_1_0.txt)
*/
//===========================... | 36.318182 | 100 | 0.539424 | chronos38 |
c8a7ef6a4fc0e3497ca846118fe07bfbd8156595 | 929 | hpp | C++ | include/eve/algo/concepts/zip_to_range.hpp | clayne/eve | dc268b5db474376e1c53f5a474f5bb42b7c4cb59 | [
"MIT"
] | null | null | null | include/eve/algo/concepts/zip_to_range.hpp | clayne/eve | dc268b5db474376e1c53f5a474f5bb42b7c4cb59 | [
"MIT"
] | null | null | null | include/eve/algo/concepts/zip_to_range.hpp | clayne/eve | dc268b5db474376e1c53f5a474f5bb42b7c4cb59 | [
"MIT"
] | null | null | null | //==================================================================================================
/*
EVE - Expressive Vector Engine
Copyright : EVE Contributors & Maintainers
SPDX-License-Identifier: MIT
*/
//==================================================================================================
#pr... | 29.967742 | 100 | 0.559742 | clayne |
c8a83eb379935d417ab6f5afa37ff6a4bdb5ee52 | 4,898 | cpp | C++ | lab3.cpp | nklapste/ece_315_lab_3 | 2bbbcd05c83e6ed8833a967a21db3aab1db32a9d | [
"MIT"
] | null | null | null | lab3.cpp | nklapste/ece_315_lab_3 | 2bbbcd05c83e6ed8833a967a21db3aab1db32a9d | [
"MIT"
] | null | null | null | lab3.cpp | nklapste/ece_315_lab_3 | 2bbbcd05c83e6ed8833a967a21db3aab1db32a9d | [
"MIT"
] | null | null | null | /*
* lab3.cpp
*
* Created on: Mar 13, 2019
* Author: Nathan Klapstein
*/
#include <predef.h>
#include <stdio.h>
#include <ctype.h>
#include <startnet.h>
#include <autoupdate.h>
#include <smarttrap.h>
#include <taskmon.h>
#include <NetworkDebug.h>
#include "AD.h"
#include "DA.h"
#include "LCD.h"
extern "C"... | 21.295652 | 114 | 0.658432 | nklapste |
c8a8725ed614bcf63b701b3d956082746cd92963 | 8,394 | cpp | C++ | src/behaviortree/nodes/composites/parallel.cpp | zja147/behaviac | 2e9c53c8368cf451139d50db01276e3f9da78733 | [
"BSD-3-Clause"
] | null | null | null | src/behaviortree/nodes/composites/parallel.cpp | zja147/behaviac | 2e9c53c8368cf451139d50db01276e3f9da78733 | [
"BSD-3-Clause"
] | null | null | null | src/behaviortree/nodes/composites/parallel.cpp | zja147/behaviac | 2e9c53c8368cf451139d50db01276e3f9da78733 | [
"BSD-3-Clause"
] | null | null | null | /////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Tencent is pleased to support the open source community by making behaviac available.
//
// Copyright (C) 2015-2017 THL A29 Limited, a Tencent company. All rights reserved.
//
// Licensed under the BSD 3... | 33.846774 | 149 | 0.560043 | zja147 |
c8aa61a07552b8493e57baacb0ae1efd9abb1537 | 4,469 | cpp | C++ | src/hip/SELF_Model.cpp | FluidNumerics/self-fluids | 98293579cd438e51d45ea136eecb930ff54c3f25 | [
"BSD-3-Clause"
] | 1 | 2018-07-22T15:03:31.000Z | 2018-07-22T15:03:31.000Z | src/hip/SELF_Model.cpp | FluidNumerics/self-fluids | 98293579cd438e51d45ea136eecb930ff54c3f25 | [
"BSD-3-Clause"
] | 15 | 2018-05-30T14:51:15.000Z | 2018-07-13T06:06:00.000Z | src/hip/SELF_Model.cpp | FluidNumerics/SELF-Fluids | 98293579cd438e51d45ea136eecb930ff54c3f25 | [
"BSD-3-Clause"
] | null | null | null | #include <hip/hip_runtime.h>
#include "SELF_HIP_Macros.h"
__global__ void UpdateSolution_Model1D_gpu(real *solution, real *dSdt, real dt, int N, int nVar){
size_t iVar = blockIdx.x;
size_t iEl = blockIdx.y;
size_t i = threadIdx.x;
solution[SC_1D_INDEX(i,iVar,iEl,N,nVar)] += dt*dSdt[SC_1D_INDEX(i,iVar,iEl,N... | 32.151079 | 139 | 0.68606 | FluidNumerics |
c8aad589036ab57563a3fb0389b1f6ffe6b35595 | 13,524 | hpp | C++ | src/noise/quantum_error.hpp | jakelishman/qiskit-aer | 7512ecede820e0d2bc7ad7b6704bcf06a861ca3a | [
"Apache-2.0"
] | 313 | 2018-12-19T09:19:12.000Z | 2022-03-21T18:15:41.000Z | src/noise/quantum_error.hpp | jakelishman/qiskit-aer | 7512ecede820e0d2bc7ad7b6704bcf06a861ca3a | [
"Apache-2.0"
] | 933 | 2018-12-21T02:56:49.000Z | 2022-03-30T01:19:54.000Z | src/noise/quantum_error.hpp | jakelishman/qiskit-aer | 7512ecede820e0d2bc7ad7b6704bcf06a861ca3a | [
"Apache-2.0"
] | 313 | 2018-12-19T14:52:55.000Z | 2022-02-28T20:20:14.000Z | /**
* This code is part of Qiskit.
*
* (C) Copyright IBM 2018, 2019.
*
* This code is licensed under the Apache License, Version 2.0. You may
* obtain a copy of this license in the LICENSE.txt file in the root directory
* of this source tree or at http://www.apache.org/licenses/LICENSE-2.0.
*
* Any modificatio... | 34.237975 | 105 | 0.619269 | jakelishman |
c8af7dd0b1e8bab893d6944622d50f80760346d3 | 4,239 | hpp | C++ | engine/executor/include/model.hpp | huggingface/neural-compressor | aaad4c357a86914ffa583753c9a26d949838a2a5 | [
"Apache-2.0"
] | 52 | 2020-08-04T04:31:48.000Z | 2020-11-29T02:34:32.000Z | engine/executor/include/model.hpp | intel/lp-opt-tool | 130eefa3586b38df6c0ff78cc8807ae273f6a63f | [
"Apache-2.0"
] | null | null | null | engine/executor/include/model.hpp | intel/lp-opt-tool | 130eefa3586b38df6c0ff78cc8807ae273f6a63f | [
"Apache-2.0"
] | 7 | 2020-08-21T01:08:55.000Z | 2020-11-29T03:36:55.000Z | // Copyright (c) 2021 Intel Corporation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or... | 36.543103 | 97 | 0.718802 | huggingface |
c8b34ae4f19227892a1c611ff7a2191a9f9185dd | 3,932 | hpp | C++ | openstudiocore/src/utilities/core/Application.hpp | ORNL-BTRIC/OpenStudio | 878f94bebf6f025445d1373e8b2304ececac16d8 | [
"blessing"
] | null | null | null | openstudiocore/src/utilities/core/Application.hpp | ORNL-BTRIC/OpenStudio | 878f94bebf6f025445d1373e8b2304ececac16d8 | [
"blessing"
] | null | null | null | openstudiocore/src/utilities/core/Application.hpp | ORNL-BTRIC/OpenStudio | 878f94bebf6f025445d1373e8b2304ececac16d8 | [
"blessing"
] | null | null | null | /**********************************************************************
* Copyright (c) 2008-2014, Alliance for Sustainable Energy.
* All rights reserved.
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published ... | 36.747664 | 99 | 0.694557 | ORNL-BTRIC |
c8b3cd5099a8215296f3b9eea9112369767dbda9 | 1,895 | cc | C++ | faster_tokenizers/faster_tokenizers/src/normalizers/unicode.cc | Beacontownfc/PaddleNLP | cec1caf485f2552a678a1d56a182d399106eeff3 | [
"Apache-2.0"
] | null | null | null | faster_tokenizers/faster_tokenizers/src/normalizers/unicode.cc | Beacontownfc/PaddleNLP | cec1caf485f2552a678a1d56a182d399106eeff3 | [
"Apache-2.0"
] | null | null | null | faster_tokenizers/faster_tokenizers/src/normalizers/unicode.cc | Beacontownfc/PaddleNLP | cec1caf485f2552a678a1d56a182d399106eeff3 | [
"Apache-2.0"
] | null | null | null | /* Copyright (c) 2022 PaddlePaddle Authors. All Rights Reserved.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or... | 30.564516 | 79 | 0.658575 | Beacontownfc |
c8b584994a98cdf021c2d37accff3055b5be81b4 | 15,405 | cc | C++ | Mozc-for-iOS/src/rewriter/user_boundary_history_rewriter_test.cc | spanfish/JapaneseKeyboard | 84fa7ef799d145fb9897b6e86bc7bc50610ccb2b | [
"Apache-2.0"
] | 33 | 2015-01-21T09:50:21.000Z | 2022-02-12T15:18:25.000Z | src/rewriter/user_boundary_history_rewriter_test.cc | kishikawakatsumi/Mozc-for-iOS | 45b0856ed8a22d5fa6b4471548389cbde4abcf10 | [
"Apache-2.0"
] | 1 | 2015-05-12T06:26:54.000Z | 2017-11-01T14:43:35.000Z | Mozc-for-iOS/src/rewriter/user_boundary_history_rewriter_test.cc | spanfish/JapaneseKeyboard | 84fa7ef799d145fb9897b6e86bc7bc50610ccb2b | [
"Apache-2.0"
] | 8 | 2015-06-08T15:57:25.000Z | 2019-05-15T08:52:58.000Z | // Copyright 2010-2014, Google Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions are
// met:
//
// * Redistributions of source code must retain the above copyright
// notice, this list of condit... | 34.233333 | 80 | 0.771892 | spanfish |
c8b5f499b86355b2f06d18af2b58493871a28c6a | 20,032 | cpp | C++ | XBoxController_UART/LynxStructure.cpp | Kjelland/lynxLib | d3e8c6f9df19d258438451aec14a0a6cfc49bf1e | [
"Apache-2.0"
] | null | null | null | XBoxController_UART/LynxStructure.cpp | Kjelland/lynxLib | d3e8c6f9df19d258438451aec14a0a6cfc49bf1e | [
"Apache-2.0"
] | null | null | null | XBoxController_UART/LynxStructure.cpp | Kjelland/lynxLib | d3e8c6f9df19d258438451aec14a0a6cfc49bf1e | [
"Apache-2.0"
] | null | null | null | //------------------------------------------------------------------------------------------------------------------------------
//--------------------------------------------------- Version 1.2.0.3 ----------------------------------------------------------
//----------------------------------------------------------... | 21.632829 | 140 | 0.586911 | Kjelland |
c8b725ef7e1bf610a9eb04257b0cc95177250cb1 | 2,020 | hpp | C++ | ysu/core_test/fakes/websocket_client.hpp | lik2129/ysu_coin | 47e40ed5d4000fc59566099929bd08a9ae16a4c1 | [
"BSD-3-Clause"
] | null | null | null | ysu/core_test/fakes/websocket_client.hpp | lik2129/ysu_coin | 47e40ed5d4000fc59566099929bd08a9ae16a4c1 | [
"BSD-3-Clause"
] | null | null | null | ysu/core_test/fakes/websocket_client.hpp | lik2129/ysu_coin | 47e40ed5d4000fc59566099929bd08a9ae16a4c1 | [
"BSD-3-Clause"
] | null | null | null | #pragma once
#include <ysu/boost/asio/connect.hpp>
#include <ysu/boost/asio/ip/tcp.hpp>
#include <ysu/boost/beast/core.hpp>
#include <ysu/boost/beast/websocket.hpp>
#include <ysu/node/websocket.hpp>
#include <chrono>
using namespace std::chrono_literals;
namespace
{
// Creates its own io context
class fake_websocke... | 26.933333 | 136 | 0.682178 | lik2129 |
c8bab8baf9ef025c36c65a426b2fec85107f75db | 5,451 | cpp | C++ | core/block_validation.cpp | tradingsecret/beam_wallet | abfe5dbb6c2fe325839887271150ae8e996e100f | [
"Apache-2.0"
] | 631 | 2018-11-10T05:56:05.000Z | 2022-03-30T13:21:00.000Z | core/block_validation.cpp | tradingsecret/beam_wallet | abfe5dbb6c2fe325839887271150ae8e996e100f | [
"Apache-2.0"
] | 1,824 | 2018-11-08T11:32:58.000Z | 2022-03-28T12:33:03.000Z | core/block_validation.cpp | tradingsecret/beam_wallet | abfe5dbb6c2fe325839887271150ae8e996e100f | [
"Apache-2.0"
] | 216 | 2018-11-12T08:07:21.000Z | 2022-03-08T20:50:19.000Z | // Copyright 2018 The Beam Team
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in... | 22.903361 | 135 | 0.657127 | tradingsecret |
c8bb0e3f2d11e5d163915b3ed35495902bd38a23 | 9,883 | cc | C++ | content/browser/renderer_host/ime_adapter_android.cc | quisquous/chromium | b25660e05cddc9d0c3053b3514f07037acc69a10 | [
"BSD-3-Clause"
] | 2 | 2020-06-10T07:15:26.000Z | 2020-12-13T19:44:12.000Z | content/browser/renderer_host/ime_adapter_android.cc | quisquous/chromium | b25660e05cddc9d0c3053b3514f07037acc69a10 | [
"BSD-3-Clause"
] | null | null | null | content/browser/renderer_host/ime_adapter_android.cc | quisquous/chromium | b25660e05cddc9d0c3053b3514f07037acc69a10 | [
"BSD-3-Clause"
] | null | null | null | // Copyright (c) 2012 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
#include "content/browser/renderer_host/ime_adapter_android.h"
#include <android/input.h>
#include "base/android/jni_android.h"
#include "base/andro... | 35.55036 | 85 | 0.667206 | quisquous |
c8bdad5426dad3092a3b8dee11834635464cba86 | 1,180 | cpp | C++ | _src/codegen/cgasm.cpp | jabdoa2/blitzmax | 0ada3c9a134178038c8f6ca67d5a004aa03f24f5 | [
"Zlib"
] | 146 | 2015-09-21T05:58:10.000Z | 2022-03-13T09:56:31.000Z | _src/codegen/cgasm.cpp | jabdoa2/blitzmax | 0ada3c9a134178038c8f6ca67d5a004aa03f24f5 | [
"Zlib"
] | 20 | 2015-09-21T09:59:37.000Z | 2022-03-21T18:44:14.000Z | _src/codegen/cgasm.cpp | jabdoa2/blitzmax | 0ada3c9a134178038c8f6ca67d5a004aa03f24f5 | [
"Zlib"
] | 62 | 2015-09-21T06:33:46.000Z | 2022-01-02T17:54:41.000Z |
#include "cgstd.h"
#include "cgasm.h"
#include "cgutil.h"
struct UseFinder : public CGVisitor{
CGAsm *as;
UseFinder( CGAsm *as ):as(as){}
CGExp *visit( CGExp *e ){
CGReg *r=e->reg();
while( r ){
as->use.insert(r->id);
r=r->owner;
}
return e;
}
};
CGAsm::CGAsm( CGStm *t,const char *s ):succ(0),pr... | 15.526316 | 79 | 0.581356 | jabdoa2 |
c8bea522a582f7ecbd312350b13a2b1ee79ceb6c | 7,273 | cpp | C++ | libs/utils/src/Log.cpp | bytememofo/filament | b0ab4c7321822b2f4e916e6b5fc7c4203f017886 | [
"Apache-2.0"
] | 1 | 2019-02-13T04:38:26.000Z | 2019-02-13T04:38:26.000Z | libs/utils/src/Log.cpp | ajweeks/filament | 2c85725d9e9c407e9bb4cd8a2ba9e6b44af3fd44 | [
"Apache-2.0"
] | null | null | null | libs/utils/src/Log.cpp | ajweeks/filament | 2c85725d9e9c407e9bb4cd8a2ba9e6b44af3fd44 | [
"Apache-2.0"
] | null | null | null | /*
* Copyright (C) 2015 The Android Open Source Project
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by app... | 26.351449 | 83 | 0.632064 | bytememofo |
c8c0be7f2063b91e710a6df88040e8735586e6d6 | 1,629 | cc | C++ | lib/src/runtime/values/array.cc | puppetlabs/puppetcpp | 45c86f43414d5f6f76f49fc3a4c7e237e4fa2b04 | [
"Apache-2.0"
] | 22 | 2015-12-08T08:54:32.000Z | 2019-04-28T11:31:04.000Z | lib/src/runtime/values/array.cc | puppetlabs/puppetcpp | 45c86f43414d5f6f76f49fc3a4c7e237e4fa2b04 | [
"Apache-2.0"
] | 37 | 2015-12-04T20:31:38.000Z | 2017-04-17T05:00:25.000Z | lib/src/runtime/values/array.cc | puppetlabs/puppetcpp | 45c86f43414d5f6f76f49fc3a4c7e237e4fa2b04 | [
"Apache-2.0"
] | 6 | 2015-12-04T19:54:57.000Z | 2021-03-24T12:16:46.000Z | #include <puppet/runtime/values/value.hpp>
#include <boost/functional/hash.hpp>
using namespace std;
namespace puppet { namespace runtime { namespace values {
void array::join(ostream& os, string const& separator) const
{
bool first = true;
for (auto const& element : *this) {
if (... | 23.955882 | 67 | 0.475752 | puppetlabs |
c8c21fb2930622d349c6c3314126de7657e6c43d | 6,160 | hpp | C++ | sdk/storage/azure-storage-blobs/inc/azure/storage/blobs/blob_batch_client.hpp | lordgamez/azure-sdk-for-cpp | 78e34a218926ac43fb06d54190b6c746eeb63692 | [
"MIT"
] | null | null | null | sdk/storage/azure-storage-blobs/inc/azure/storage/blobs/blob_batch_client.hpp | lordgamez/azure-sdk-for-cpp | 78e34a218926ac43fb06d54190b6c746eeb63692 | [
"MIT"
] | null | null | null | sdk/storage/azure-storage-blobs/inc/azure/storage/blobs/blob_batch_client.hpp | lordgamez/azure-sdk-for-cpp | 78e34a218926ac43fb06d54190b6c746eeb63692 | [
"MIT"
] | null | null | null | // Copyright (c) Microsoft Corporation. All rights reserved.
// SPDX-License-Identifier: MIT
#pragma once
#include "azure/storage/blobs/blob_service_client.hpp"
namespace Azure { namespace Storage { namespace Blobs {
/**
* @brief A BlobBatch allows you to batch multiple Azure Storage operations in a single req... | 36.886228 | 99 | 0.700649 | lordgamez |
c8c4ee498faa938663c0243da7df485212965077 | 25,372 | cpp | C++ | project/src/common/Graphics.cpp | delahee/lime | c4bc1ff140fa27c12f580fa3b518721e2a8266f2 | [
"MIT"
] | 1 | 2020-09-16T15:18:39.000Z | 2020-09-16T15:18:39.000Z | openfl_lime/src/common/Graphics.cpp | wannaphong/flappy | bc4630ca9120463c57c1d756c39c60a6dc509940 | [
"MIT"
] | 1 | 2020-11-17T00:58:59.000Z | 2020-11-17T00:58:59.000Z | openfl_lime/src/common/Graphics.cpp | wannaphong/flappy | bc4630ca9120463c57c1d756c39c60a6dc509940 | [
"MIT"
] | null | null | null | #include <Graphics.h>
#include "renderer/common/Surface.h"
#include <Display.h>
namespace lime
{
void Graphics::OnChanged()
{
mVersion++;
if (mOwner && !(mOwner->mDirtyFlags & dirtExtent))
mOwner->DirtyExtent();
}
// TODO: invlidate/cache extents (do for whole lot at once)
Graphics::Graphics(DisplayO... | 24.704966 | 110 | 0.563377 | delahee |
c8c6968952781985673d807905504eae08d101a1 | 47,098 | cc | C++ | tests/ut/ge/graph/load/new_model_manager_davinci_model_unittest.cc | TommyLike/graphengine | da2c616522cc078c2573eca8422ff70fda229efb | [
"Apache-2.0"
] | null | null | null | tests/ut/ge/graph/load/new_model_manager_davinci_model_unittest.cc | TommyLike/graphengine | da2c616522cc078c2573eca8422ff70fda229efb | [
"Apache-2.0"
] | null | null | null | tests/ut/ge/graph/load/new_model_manager_davinci_model_unittest.cc | TommyLike/graphengine | da2c616522cc078c2573eca8422ff70fda229efb | [
"Apache-2.0"
] | null | null | null | /**
* Copyright 2019-2020 Huawei Technologies Co., Ltd
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
* http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicabl... | 32.661581 | 120 | 0.754321 | TommyLike |
c8c7abc9269b32f16484af7a9b0f8a9a4055f476 | 2,876 | hh | C++ | TFM/click-2.0.1/elements/grid/ackretrysender.hh | wangyang2013/TFM | cabca56229a7e4dafc76da8d631980fc453c9493 | [
"BSD-3-Clause"
] | 3 | 2018-04-14T14:43:31.000Z | 2019-12-06T13:09:58.000Z | TFM/click-2.0.1/elements/grid/ackretrysender.hh | nfvproject/TFM | cabca56229a7e4dafc76da8d631980fc453c9493 | [
"BSD-3-Clause"
] | null | null | null | TFM/click-2.0.1/elements/grid/ackretrysender.hh | nfvproject/TFM | cabca56229a7e4dafc76da8d631980fc453c9493 | [
"BSD-3-Clause"
] | null | null | null | #ifndef CLICK_ACKRETRYSENDER_HH
#define CLICK_ACKRETRYSENDER_HH
#include <click/element.hh>
#include <click/etheraddress.hh>
#include <click/packet.hh>
#include <click/task.hh>
#include <click/timer.hh>
#include <click/dequeue.hh>
CLICK_DECLS
/*
* =c
* ACKRetrySender(I<KEYWORDS>)
*
* =s Grid
* Resend packets unti... | 24.581197 | 78 | 0.697497 | wangyang2013 |
c8c821ad3342bdc17c357c554a2d9a777714ab2f | 12,649 | cxx | C++ | printscan/print/spooler/spoolss/win32/pool.cxx | npocmaka/Windows-Server-2003 | 5c6fe3db626b63a384230a1aa6b92ac416b0765f | [
"Unlicense"
] | 17 | 2020-11-13T13:42:52.000Z | 2021-09-16T09:13:13.000Z | printscan/print/spooler/spoolss/win32/pool.cxx | sancho1952007/Windows-Server-2003 | 5c6fe3db626b63a384230a1aa6b92ac416b0765f | [
"Unlicense"
] | 2 | 2020-10-19T08:02:06.000Z | 2020-10-19T08:23:18.000Z | printscan/print/spooler/spoolss/win32/pool.cxx | sancho1952007/Windows-Server-2003 | 5c6fe3db626b63a384230a1aa6b92ac416b0765f | [
"Unlicense"
] | 14 | 2020-11-14T09:43:20.000Z | 2021-08-28T08:59:57.000Z | /*++
Copyright (c) 1990-2002 Microsoft Corporation
Module Name:
pool.cxx
Abstract:
Implementation for class ThreadPool.
Author:
Ali Naqvi (alinaqvi) 3-May-2002
Revision History:
--*/
#include <precomp.h>
#include "pool.hxx"
#pragma hdrstop
#define SIZE_OF_TOKEN_INFORM... | 20.20607 | 116 | 0.54028 | npocmaka |
c8c84c07fdf7eba54f87f0fb5902abc3edadd060 | 3,125 | hpp | C++ | src/Renderer/VulkanRendererImpl.hpp | mxtt-mmxix/York-Engine | a4592757b2fe52b4737c87ba59546dce2e90b9dd | [
"BSD-2-Clause"
] | null | null | null | src/Renderer/VulkanRendererImpl.hpp | mxtt-mmxix/York-Engine | a4592757b2fe52b4737c87ba59546dce2e90b9dd | [
"BSD-2-Clause"
] | null | null | null | src/Renderer/VulkanRendererImpl.hpp | mxtt-mmxix/York-Engine | a4592757b2fe52b4737c87ba59546dce2e90b9dd | [
"BSD-2-Clause"
] | null | null | null | /*
* BSD 2-Clause License
*
* Copyright (c) 2022 Matthew McCall
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without
* modification, are permitted provided that the following conditions are met:
*
* 1. Redistributions of source code must retain the above copyright notic... | 30.637255 | 85 | 0.73824 | mxtt-mmxix |
c8c9158acca4f039fb52fe16fea629017db67bd7 | 263 | cpp | C++ | LeetCode/Problems/Algorithms/#70_ClimbingStairs_sol5_dp_O(N)_time_O(1)_extra_space.cpp | Tudor67/Competitive-Programming | ae4dc6ed8bf76451775bf4f740c16394913f3ff1 | [
"MIT"
] | 1 | 2022-01-26T14:50:07.000Z | 2022-01-26T14:50:07.000Z | LeetCode/Problems/Algorithms/#70_ClimbingStairs_sol5_dp_O(N)_time_O(1)_extra_space.cpp | Tudor67/Competitive-Programming | ae4dc6ed8bf76451775bf4f740c16394913f3ff1 | [
"MIT"
] | null | null | null | LeetCode/Problems/Algorithms/#70_ClimbingStairs_sol5_dp_O(N)_time_O(1)_extra_space.cpp | Tudor67/Competitive-Programming | ae4dc6ed8bf76451775bf4f740c16394913f3ff1 | [
"MIT"
] | null | null | null | class Solution {
public:
int climbStairs(int n) {
vector<int> f(2);
f[0] = 1;
f[1] = 1;
for(int i = 2; i <= n; ++i){
f[i % 2] = f[(i - 1) % 2] + f[(i - 2) % 2];
}
return f[n % 2];
}
}; | 21.916667 | 56 | 0.323194 | Tudor67 |
c8ca97ce5aeeb3d8b036d29649275e2f49bba83a | 1,688 | cpp | C++ | openscenario/openscenario_interpreter/src/syntax/longitudinal_action.cpp | WJaworskiRobotec/scenario_simulator_v2 | c23497ac8716dcefef20d4b5a4ff1185e01f48e6 | [
"Apache-2.0"
] | 45 | 2021-04-12T22:43:25.000Z | 2022-02-27T23:57:53.000Z | openscenario/openscenario_interpreter/src/syntax/longitudinal_action.cpp | WJaworskiRobotec/scenario_simulator_v2 | c23497ac8716dcefef20d4b5a4ff1185e01f48e6 | [
"Apache-2.0"
] | 140 | 2021-04-13T04:28:19.000Z | 2022-03-30T12:44:32.000Z | openscenario/openscenario_interpreter/src/syntax/longitudinal_action.cpp | WJaworskiRobotec/scenario_simulator_v2 | c23497ac8716dcefef20d4b5a4ff1185e01f48e6 | [
"Apache-2.0"
] | 13 | 2021-05-22T02:24:49.000Z | 2022-03-25T05:16:31.000Z | // Copyright 2015-2021 Tier IV, Inc. All rights reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by app... | 35.166667 | 150 | 0.719787 | WJaworskiRobotec |
c8cbba8523b7d615d28bf710acc233688249f5e0 | 49,224 | cpp | C++ | src/caffe/test/test_convolution_layer.cpp | Amanda-Barbara/nvcaffe | 5155a708b235a818ce300aa3f9fc235ece9a35fb | [
"BSD-2-Clause"
] | 758 | 2015-03-08T20:54:38.000Z | 2022-01-11T03:14:51.000Z | src/caffe/test/test_convolution_layer.cpp | Matsuko9/caffe | 17e347e42e664b87d80f63bfbbb89bec5e559242 | [
"BSD-2-Clause"
] | 493 | 2015-04-28T00:08:53.000Z | 2021-08-04T07:26:54.000Z | src/caffe/test/test_convolution_layer.cpp | Matsuko9/caffe | 17e347e42e664b87d80f63bfbbb89bec5e559242 | [
"BSD-2-Clause"
] | 389 | 2015-03-05T12:11:44.000Z | 2022-03-13T21:49:42.000Z | #include <algorithm>
#include <vector>
#include "gtest/gtest.h"
#include "caffe/blob.hpp"
#include "caffe/common.hpp"
#include "caffe/filler.hpp"
#include "caffe/layers/conv_layer.hpp"
#ifdef USE_CUDNN
#include "caffe/layers/cudnn_conv_layer.hpp"
#endif
#include "caffe/test/test_caffe_main.hpp"
#include "caffe/te... | 43.216857 | 98 | 0.714855 | Amanda-Barbara |
c8cd66f298091f7fe74213346ca09586eccc8eba | 506 | cpp | C++ | CHAPTER11/C11E12.cpp | lrpinnto/stroustrup-exercises | a471a0d7b49b51b7c26e005ff9e66f3f6db199dd | [
"MIT"
] | null | null | null | CHAPTER11/C11E12.cpp | lrpinnto/stroustrup-exercises | a471a0d7b49b51b7c26e005ff9e66f3f6db199dd | [
"MIT"
] | null | null | null | CHAPTER11/C11E12.cpp | lrpinnto/stroustrup-exercises | a471a0d7b49b51b7c26e005ff9e66f3f6db199dd | [
"MIT"
] | null | null | null | #include "../stroustrup/std_lib_facilities.h"
//CHAPTER 11 EX 12
int main()
{
cout<<"Enter a text file: ";
string iname;
cin>>iname;
ifstream ifs {iname};
if (!ifs) error("can't open input file",iname);
ifs.exceptions(ifs.exceptions()|ios_base::badbit);
string line;
while(getline(ifs, ... | 21.083333 | 54 | 0.55336 | lrpinnto |
c8cf8fad3cc65b8131302bde5e253a654d48bac8 | 5,870 | cpp | C++ | build/linux-build/Sources/src/kha/kore/Sound.cpp | HedgehogFog/TimeOfDeath | b78abacf940e1a88c8b987d99764ebb6876c5dc6 | [
"MIT"
] | null | null | null | build/linux-build/Sources/src/kha/kore/Sound.cpp | HedgehogFog/TimeOfDeath | b78abacf940e1a88c8b987d99764ebb6876c5dc6 | [
"MIT"
] | null | null | null | build/linux-build/Sources/src/kha/kore/Sound.cpp | HedgehogFog/TimeOfDeath | b78abacf940e1a88c8b987d99764ebb6876c5dc6 | [
"MIT"
] | null | null | null | // Generated by Haxe 4.0.0-preview.5
#include <hxcpp.h>
#ifndef INCLUDED_StringTools
#include <hxinc/StringTools.h>
#endif
#ifndef INCLUDED_haxe_Log
#include <hxinc/haxe/Log.h>
#endif
#ifndef INCLUDED_haxe_io_Bytes
#include <hxinc/haxe/io/Bytes.h>
#endif
#ifndef INCLUDED_kha_Resource
#include <hxinc/kha/Resource.h>
#e... | 33.352273 | 208 | 0.716014 | HedgehogFog |